# Hdi Dictionary

> by Zygmunt Frajzyngier and Paul Eguchi and Roger Prafé and Megan Schwabauer with Erin Shay and Henry Tourneux

This repository contains the data underlying the published version of the dictionary
at [Dictionaria](https://dictionaria.clld.org/contributions/hdi) as [CLDF](https://cldf.clld.org)
[Dictionary](cldf)
[![CLDF validation](https://github.com/dictionaria/hdi/workflows/CLDF-validation/badge.svg)](https://github.com/dictionaria/hdi/actions?query=workflow%3ACLDF-validation)

Releases of this repository are archived with and accessible through
[ZENODO](https://zenodo.org/communities/dictionaria) and the latest release
is published on the [Dictionaria website](https://dictionaria.clld.org).

<h2 id="Introduction">Introduction</h2>
<h3 id="Geographical location and speakers">Geographical location and speakers</h3>

Hdi (_gwáɗ-á xdí_ ‘language of Hdi’ or simply _xdí_ in Hdi) is a Central Chadic language spoken in the Far North Province of Cameroon. The name _hidé_ has been used in administrative documents in reference to the people who speak the language. The main town where the language is spoken is Tourou, located at 10° 55' 25" N latitude and 13° 44' 05" E longitude, right on the border between Cameroon and Nigeria, about one hour’s drive north from Mokolo. The estimates of the number of speakers of Hdi range between 10,000 and 25,000. Some speakers of Hdi have migrated to Nigeria, specifically to Mubi and Yola, where the Hdi communities may number several thousand speakers.

Some Hdi speakers (the number is not available) are bilingual or trilingual, with French and Hausa being the second and third languages. As of 2014, a substantial number of speakers have received primary education, as there are five elementary schools in Tourou. The great majority of Hdi are farmers. 

At the end of the 19th and the beginning of the 20th century, the town of Tourou was under considerable social stress, as it was the object of frequent raids by the infamous slave trader Hamman Yaji (Vaughan and Kirk-Greene 1995). The men he captured were forced to build the road between Mokolo and Tourou. The remnants of Hamman Yaji’s outpost can still be seen in Tourou. His raids had long-lasting effects on the Hdi community, as speakers were reluctant for a long time to send their children to school for fear that this was another way of depriving them of their sons and daughters. 

The town is a tourist attraction, mainly because of the market it holds on Thursdays and the characteristic painted calabashes that women wear as hats. Photographs from the marketplace in Tourou are widely available on the internet. 

The purpose of the grammatical sketch that follows is to present, in an abbreviated form, the main formal coding means and functions encoded in the grammatical system of the language. 

For a fuller description the reader is referred to Frajzyngier with Shay 2002. 

A number of modifications that incorporate the results of the more recent fieldwork and research are accompanied by minimal supporting evidence. 

In the present introduction, Hdi words in the text are in italics, their translations are in inverted commas. 

<h3 id="Organization and representation in the dictionary">Organization and representation in the dictionary</h3>

All Hdi material in the dictionary is marked by bold font. The usual entry consists of the lexical item followed by the indicator of its categoriality, translation into English, translation into French, and examples of its use. 

For verbs, the main entries are forms ending in a vowel, so that the tone(s) of the verb can be represented. Within the entry, forms are cited in the perfective aspect, often in the third-person singular; these forms are sometimes translated into English and French as the infinitive form and sometimes as the third-person singular perfective form. No significance should be attached to whether the verb entry is translated as the third-person singular or as the infinitive in English or French. For a number of verbs, examples containing extensions are added mainly in order to attest to the possibility of such additions. Occasionally the entries include examples from natural discourse, as represented in Frajzyngier with Shay 2002. The verbs with extensions are grouped under the main entry and are also listed in their alphabetical order.

Entries for nouns indicate the ontological class of nouns, e.g. whether the term refers to fauna or flora, and even narrower specifications within the two classes. These classifications have no grammatical consequences. The botanical forms in Fula come from two sources. The first one is Roger Prafé’s identification of names of Hdi plants in Fula, obtained through a series of interviews with a Fula Bororo speaker. The second source consists of terms included in Tourneux and Daïrou 1998 and Noye 1989. The forms obtained through the interviews with the Bororo speaker are more numerous, because they include plants that are not necessarily part of agricultural practice. The identification of insects was done with the help of Boorman 1981, and the identification of birds with the help of Serle and Morel 1993. The identification of mammals was done with the help of Halternorth and Diller 1985.

Nominal and verbal entries occasionally include an explanation of customs, ceremonies, and practices in which a given activity, as represented by a verb, or a given entity, as represented by a noun, plays a role. These descriptions derive entirely from information provided by Roger Prafé and do not necessarily carry the expected accuracy of anthropological field research. 

<h2 id="Phonology">Phonology</h2>
<h3 id="Phonetic and phonological inventories">Phonetic and phonological inventories</h3>

The consonantal system is characterized by the presence of voiced, voiceless, and glottalized stops. The palatal articulation is represented only by the glide y. Underlying consonants do not include palatal continuants, affricates, and nasals.

  

<table class="table table-bordered">
<caption>Table 1: Underlying consonants</caption>
<thead>
<tr>
<th></th>
<th>Bilabial</th>
<th>Labio-Dental</th>
<th>Alveolar</th>
<th>Palatal</th>
<th>Velar</th>
</tr>
</thead>
<tbody>
<tr>
<td>Stops</td>
<td></td>
<td></td>
<td></td>
<td></td>
<td></td>
</tr>
<tr>
<td>Voiced</td>
<td>b</td>
<td></td>
<td>d</td>
<td></td>
<td>g</td>
</tr>
<tr>
<td>Voiceless</td>
<td>p</td>
<td></td>
<td>t</td>
<td></td>
<td>k</td>
</tr>
<tr>
<td>Prenasalized</td>
<td>mb</td>
<td></td>
<td>md, nd</td>
<td></td>
<td>ng</td>
</tr>
<tr>
<td>Glottalized</td>
<td>ɓ</td>
<td></td>
<td>ɗ</td>
<td></td>
<td></td>
</tr>
<tr>
<td>Affricates</td>
<td></td>
<td></td>
<td></td>
<td></td>
<td></td>
</tr>
<tr>
<td>Voiced</td>
<td></td>
<td></td>
<td>dz, ndz</td>
<td></td>
<td></td>
</tr>
<tr>
<td>Voiceless</td>
<td></td>
<td></td>
<td>ts</td>
<td></td>
<td></td>
</tr>
<tr>
<td>Continuants</td>
<td></td>
<td></td>
<td></td>
<td></td>
<td></td>
</tr>
<tr>
<td>Voiced</td>
<td></td>
<td>v</td>
<td>z</td>
<td></td>
<td>gh</td>
</tr>
<tr>
<td>Voiceless</td>
<td></td>
<td>f</td>
<td>s</td>
<td></td>
<td>x</td>
</tr>
<tr>
<td>Lateral Continuants</td>
<td></td>
<td></td>
<td></td>
<td></td>
<td></td>
</tr>
<tr>
<td>Voiced</td>
<td></td>
<td></td>
<td>ɮ</td>
<td></td>
<td></td>
</tr>
<tr>
<td>Voiceless</td>
<td></td>
<td></td>
<td>ɬ</td>
<td></td>
<td></td>
</tr>
<tr>
<td>Nasals</td>
<td>m</td>
<td></td>
<td>n</td>
<td></td>
<td>ŋ</td>
</tr>
<tr>
<td>Liquids</td>
<td></td>
<td></td>
<td>r</td>
<td></td>
<td></td>
</tr>
<tr>
<td></td>
<td></td>
<td></td>
<td>l</td>
<td></td>
<td></td>
</tr>
<tr>
<td>Glides</td>
<td>w</td>
<td></td>
<td></td>
<td>y</td>
<td></td>
</tr>
</tbody>
</table>

  

Phonetic consonants include all of the underlying consonants plus a series of palatal continuants, the bilabial voiceless fricative, palatal nasals, the glottal stop, and glottalized glides. The following chart represents phonetic consonants:

  

<table class="table table-bordered">
<caption>Table 2: Inventory of phonetic consonants</caption>
<thead>
<tr>
<th></th>
<th>Bilabial</th>
<th>Labio-Dental</th>
<th>Alveolar</th>
<th>Palatal</th>
<th>Velar</th>
</tr>
</thead>
<tbody>
<tr>
<td>Stops</td>
<td></td>
<td></td>
<td></td>
<td></td>
<td></td>
</tr>
<tr>
<td>Voiced</td>
<td>b</td>
<td></td>
<td>d</td>
<td></td>
<td>g</td>
</tr>
<tr>
<td>Voiceless</td>
<td>p</td>
<td></td>
<td>t</td>
<td></td>
<td>k, kw</td>
</tr>
<tr>
<td>Prenasalized</td>
<td>mb</td>
<td></td>
<td>md, nd, ndz</td>
<td></td>
<td>ng</td>
</tr>
<tr>
<td>Glottalized</td>
<td>ɓ</td>
<td>'w</td>
<td>ɗ</td>
<td>'y</td>
<td></td>
</tr>
<tr>
<td>Affricates</td>
<td></td>
<td></td>
<td></td>
<td></td>
<td></td>
</tr>
<tr>
<td>Voiced</td>
<td></td>
<td></td>
<td>dz</td>
<td>i</td>
<td></td>
</tr>
<tr>
<td>Voiceless</td>
<td></td>
<td></td>
<td>ts</td>
<td>c</td>
<td></td>
</tr>
<tr>
<td>Continuants</td>
<td></td>
<td></td>
<td></td>
<td></td>
<td></td>
</tr>
<tr>
<td>Voiced</td>
<td>ß</td>
<td>v</td>
<td>z</td>
<td>ž</td>
<td>ɣ</td>
</tr>
<tr>
<td>Voiceless</td>
<td>f</td>
<td>f</td>
<td>s</td>
<td>š</td>
<td>x</td>
</tr>
<tr>
<td>Lateral Continuants</td>
<td></td>
<td></td>
<td></td>
<td></td>
<td></td>
</tr>
<tr>
<td>Voiced</td>
<td></td>
<td></td>
<td>ɮ</td>
<td></td>
<td></td>
</tr>
<tr>
<td>Voiceless</td>
<td></td>
<td></td>
<td>ɬ</td>
<td></td>
<td></td>
</tr>
<tr>
<td>Nasals</td>
<td>m</td>
<td></td>
<td>n</td>
<td></td>
<td>ŋ</td>
</tr>
<tr>
<td>Liquids</td>
<td></td>
<td></td>
<td>r</td>
<td></td>
<td></td>
</tr>
<tr>
<td></td>
<td></td>
<td></td>
<td>l</td>
<td></td>
<td></td>
</tr>
<tr>
<td>Glides</td>
<td>w</td>
<td></td>
<td></td>
<td>y</td>
<td></td>
</tr>
</tbody>
</table>

  

In the dictionary proper, the lateral voiceless continuant _ɬ_ is represented as _hl_, and the lateral voiced continuant _ɮ_ is represented as _zl_. 

Labiodental fricatives become bilabial voiceless fricatives according to the rule:

__Rule 1:__		f	→	ƒ/ \_\_\_ \[+round\], e.g. \[ƒwáɗ\] ‘four’

The bilabial voiced continuant is a product of the change of v to ß between high round vowels:

__Rule 2:__		v →	ß/u\_\_\_u, e.g. _dzvú_ after optional vowel insertion → \[jùßú\] ‘hand’

The palatal continuants are products of palatalization rules:

__Rule 3:__		\[+alveolar\] \[+cont\] →	\[+pal\]/V\[+front\], e.g. _tsí_ → \[cí\] ‘third-person singular subject’

The glottalized glides _‘w_ and _‘y_ have been recorded only when in intervocalic position, preceded by a high front or back vowel and followed by low vowel. 

The alveolar nasal becomes velar in syllable-final position and may be realized as the sequence velar nasal-velar voiced stop when followed by a vowel in another word. Consider the noun /zwán/ ‘child’. The evidence that it has the underlying alveolar nasal is provided by the plural form \[zwánì\]. In word-final position it undergoes velarization:

__Rule 4:__		n → ŋ/ \_\_\_ \#:

<table><tbody>
<tr><td><strong>
    (1)
</strong></td><td class="object-language" colspan="3"><em>zwáŋ	á		krì → [zwáŋ.gá.krì]</em></td></tr>
<tr><td></td><td class="morpheme">zwáŋ</td><td class="morpheme">á</td><td class="morpheme">krì</td></tr>
<tr><td></td><td class="gloss">child</td><td class="gloss"><span style="font-variant: small-caps;">GEN</span></td><td class="gloss">dog</td></tr>
<tr><td></td><td class="translation" colspan="3">'puppy'</td></tr>
</tbody></table>

A high back vowel becomes a glide after a velar, labial, or liquid consonant and before a, according to the following rule:

__Rule 5:__ 	u → w/C\[+velar, labial, liquid\] \_\_\_ (C)a:

<table><tbody>
<tr><td><strong>
    (2)
</strong></td><td class="object-language" colspan="3"><em>gù		á		wà → [gwà á wà]</em></td></tr>
<tr><td></td><td class="morpheme">gù</td><td class="morpheme">á</td><td class="morpheme">wà</td></tr>
<tr><td></td><td class="gloss">goat</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'it is not a goat'</td></tr>
</tbody></table>

The glottal stop occurs only between identical vowels or between a vowel and a glide that shares with the vowel the features for height or roundness. Because its presence is predictable it is not an underlying segment:

*   _zì’yá_:	‘smell’
*   _mì’í_: 	‘wives’
*   _ù’wà_:	‘milk’
*   _dzà’á_:	‘go’, future tense marker

  

<table class="table table-bordered">
<caption>Table 3: Distribution of stops within the word and at phrase boundaries</caption>
<thead>
<tr>
<th></th>
<th>Word-initial</th>
<th>Intervocalic</th>
<th>Word-final</th>
<th>Phrase-final</th>
</tr>
</thead>
<tbody>
<tr>
<td>Voiced</td>
<td>b, d, g</td>
<td>b, d, g</td>
<td>b, d, g</td>
<td></td>
</tr>
<tr>
<td>Voiceless</td>
<td>p, t, k</td>
<td>p, t, k</td>
<td>p, k, kw</td>
<td>p, k, kw</td>
</tr>
<tr>
<td>Prenasalized</td>
<td>mb, nd, ŋg</td>
<td>mb, ng</td>
<td></td>
<td></td>
</tr>
<tr>
<td>Nasal</td>
<td>n, m</td>
<td>n, m, ŋ</td>
<td>m, ŋ</td>
<td>m, ŋ</td>
</tr>
<tr>
<td>Glottalized</td>
<td>ɓ, ɗ</td>
<td>ɓ, ɗ</td>
<td>ɓ, ɗ</td>
<td></td>
</tr>
</tbody>
</table>
<table class="table table-bordered">
<caption>Table 4: Distribution of affricates and continuants</caption>
<thead>
<tr>
<th></th>
<th>Word-initial</th>
<th>Intervocalic</th>
<th>Word-final</th>
<th>Phrase-final</th>
</tr>
</thead>
<tbody>
<tr>
<td>Voiced</td>
<td>z, gh, ɮ, dz</td>
<td>z, gh, ɮ, dz</td>
<td>z</td>
<td></td>
</tr>
<tr>
<td>Voiceless</td>
<td>s, x, ɬ, ts</td>
<td>s, x, ɬ, ts</td>
<td>s, x, ɬ</td>
<td>s, x</td>
</tr>
</tbody>
</table>

  

A voiced consonant becomes voiceless when not followed by a sonorant in the next syllable:

__Rule 6:__	 C \[+voice\]	→	\[-voice\]/\_\_\_\[-son\]

Compare the behavior of the extension _gá_, which codes inner and downward movement:

<table><tbody>
<tr><td><strong>
    (3)
</strong></td><td class="object-language" colspan="2"><em>vrà-gá-vr-í dzághà</em></td></tr>
<tr><td></td><td class="morpheme">vrà-gá-vr-í</td><td class="morpheme">dzághà</td></tr>
<tr><td></td><td class="gloss">return-<span style="font-variant: small-caps;">INN</span>-return-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss">home</td></tr>
<tr><td></td><td class="translation" colspan="2">'I returned home' (from a higher elevation)</td></tr>
</tbody></table>

When the extension is not followed by a vowel, the velar consonant is voiceless even when following a vowel and preceding a voiced consonant:

<table><tbody>
<tr><td><strong>
    (4)
</strong></td><td class="object-language" colspan="2"><em>vrà-k-vr-í dzághà</em></td></tr>
<tr><td></td><td class="morpheme">vrà-k-vr-í</td><td class="morpheme">dzághà</td></tr>
<tr><td></td><td class="gloss">return-<span style="font-variant: small-caps;">INN</span>-return-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss">home</td></tr>
<tr><td></td><td class="translation" colspan="2">'I returned home' (from an equal elevation, said at the place to which the subject has returned)</td></tr>
</tbody></table>

There are more clusters allowed in the syllabic onset than in the syllabic coda. Two-consonant clusters are common in both word-initial and intervocalic position, but there are no clusters in word-final or phrase-final position. The general principle for consonant cluster formation is that the consonants in a cluster should differ maximally, i.e., they should differ in place of articulation, manner of articulation, and syllabicity properties. The two charts that follow list allowed and disallowed consonant clusters. The first chart takes into consideration the manner of articulation, the second chart the place of articulation. 

  

<table class="table table-bordered">
<caption>Table 5: Consonantal clusters and manner of articulation</caption>
<thead>
<tr>
<th></th>
<th>Stops</th>
<th>Continuants</th>
<th>Nasals</th>
<th>Liquids</th>
</tr>
</thead>
<tbody>
<tr>
<td>Stops</td>
<td>+</td>
<td>+</td>
<td>+</td>
<td>+</td>
</tr>
<tr>
<td>Continuants</td>
<td>+</td>
<td>+</td>
<td>+</td>
<td>+</td>
</tr>
<tr>
<td>Nasals</td>
<td>+</td>
<td>+</td>
<td>+</td>
<td>+</td>
</tr>
<tr>
<td>Liquids</td>
<td>+</td>
<td>+</td>
<td>+ (V_V)</td>
<td>-</td>
</tr>
</tbody>
</table>
<table class="table table-bordered">
<caption>Table 6:Consonantal clusters and place of articulation</caption>
<thead>
<tr>
<th></th>
<th>Bilabial</th>
<th>Labial</th>
<th>Alveolar</th>
<th>Velar</th>
</tr>
</thead>
<tbody>
<tr>
<td>Bilabial</td>
<td>-</td>
<td>-</td>
<td>+</td>
<td>+</td>
</tr>
<tr>
<td>Labial</td>
<td>-</td>
<td>-</td>
<td>-</td>
<td>+</td>
</tr>
<tr>
<td>Alveolar</td>
<td>-</td>
<td>stop-cont.</td>
<td>+</td>
<td>+</td>
</tr>
<tr>
<td>Velar</td>
<td>-</td>
<td>-</td>
<td>+ </td>
<td>-</td>
</tr>
</tbody>
</table>

  

The following chart represents underlying vocalic segments:

<table class="table table-bordered">
<caption>Table 7: Inventory of underlying vowels</caption>
<thead>
<tr>
<th>Front</th>
<th>Central</th>
<th>Back</th>
</tr>
</thead>
<tbody>
<tr>
<td>i</td>
<td>ə</td>
<td>u</td>
</tr>
<tr>
<td>e</td>
<td></td>
<td>a</td>
</tr>
</tbody>
</table>

  

Sporadic vowel lowering takes place when a high vowel is followed by a low vowel. The high vowel may be lowered one step:

__Rule 7:__		V\[+high\] → \[-high\] / \_\_\_CV\[+low\]

The high vowel becomes round when followed by the round glide within the same morpheme or across a morpheme boundary within the same phrase:

__Rule 8:__		V\[+high\]	→	\[+round\] /\_\_\_w

<table><tbody>
<tr><td><strong>
    (5)
</strong></td><td class="object-language" colspan="2"><em>ghùzú-á	kwálábá → [ghòzá kwálábá]</em></td></tr>
<tr><td></td><td class="morpheme">ghùzú-á</td><td class="morpheme">kwálábá</td></tr>
<tr><td></td><td class="gloss">beer-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">bottle</td></tr>
<tr><td></td><td class="translation" colspan="2">'bottled beer'</td></tr>
</tbody></table>

The morpheme-final vowel is replaced by the initial vowel of the following morpheme if the two belong to the same phrase:

__Rule 9:__		V1	→	V2/ \_\_\_ \#V2

<table><tbody>
<tr><td><strong>
    (6)
</strong></td><td class="object-language" colspan="2"><em>tá		ìmí → [tímí]</em></td></tr>
<tr><td></td><td class="morpheme">tá</td><td class="morpheme">ìmí</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">water</td></tr>
<tr><td></td><td class="translation" colspan="2">'water' (in non-subject function)</td></tr>
</tbody></table>
<h3 id="Syllable structure">Syllable structure</h3>

A syllable in Hdi has the following properties: The onset and the coda may be absent and the syllable may consist only of the nucleus, which may be a vowel or a sonorant. The onset may consist of a consonant or a cluster of consonants, CC. The coda may consist of one consonant, which may be a sonorant (including liquids and nasals), a stop, or a fricative. The alveolar nasal becomes velar in word-final position. The only phonetic consonant cluster in coda position consists of a stop followed by a glide, a result of the labialization of the final u following a velar consonant. If a disallowed syllabic onset or coda would emerge, an epenthetic vowel must be inserted. In addition, if the absence of the tone would affect the grammatical coding realized by the tone, an epenthetic vowel is inserted. The vowel is inserted into the first position where the violation of the syllabic structure occurs. The vowel from the next syllable is copied into the disallowed position or into the first position that requires a tone realization:

<table><tbody>
<tr><td><strong>
    (7)
</strong></td><td class="object-language" colspan="2"><em>kl-g-ì-xà 				ìmí			 → [klígìxà ìmí]</em></td></tr>
<tr><td></td><td class="morpheme">kl-g-ì-xà</td><td class="morpheme">ìmí</td></tr>
<tr><td></td><td class="gloss">take-<span style="font-variant: small-caps;">INN-1SG-DOWN</span></td><td class="gloss">water</td></tr>
<tr><td></td><td class="translation" colspan="2">'bring me down some water!'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (8)
</strong></td><td class="object-language" colspan="2"><em>mà		kl-d-á-f-ká					→ [mà klàdáfká]</em></td></tr>
<tr><td></td><td class="morpheme">mà</td><td class="morpheme">kl-d-á-f-ká</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">PROH</span></td><td class="gloss">take-<span style="font-variant: small-caps;">ALL-PVG-UP-2SG</span></td></tr>
<tr><td></td><td class="translation" colspan="2">'do not take it up there'</td></tr>
</tbody></table>
<h3 id="Tone">Tone</h3>

The language has two tones, high and low. Tone plays an important role in both the lexicon and the syntax of the language. In the lexicon, tone distinguishes between lexical items whose segmental structure is identical. Tone also plays an important role in the coding of the semantic roles of arguments, in the reference and nominal system, in modality coding, and in virtually all constructions in the language. All high tones in phrase-final position are lowered.

<h2 id="Lexical Categories">Lexical Categories</h2>

Lexical categories in Hdi include: nouns (marked in the dictionary as n), verbs (v), a small class of adjectives (adj), a small class of adverbs (adv), quantifiers (quant), numerals (num) and the following classes of freestanding grammatical morphemes: prepositions (prep), complementizers and subordinators (comp), deictics and determiners (det) and copulas (cop), identical in form with determiners. 

The category ‘noun’ in Hdi is defined by its inherent ability to serve as an argument of a verbal predication and as the predicate of a nominal predication. Nouns can also receive inflectional markers coding number. Among nouns there is a distinct class of proper names marked in the dictionary as npm, for names used for males, and npf, for names used for females. Since there is no grammatical gender distinction in Hdi, the distinction between names used for males and names used for females has no grammatical consequences. In the dictionary, information about the category noun is often followed in italics by information about the ontological category, such as bot (botanical), ornit (ornithological), etc. The ontological categories have no grammatical consequences of any kind. The language has also a set of independent pronouns which function as noun phrases; these are listed in the section on reference.

The category ‘verb’ is defined by its inherent ability to serve as a predicate and not as an argument. Morphologically, verbs are characterized by the ability to occur with subject and object pronouns, with verbal extensions, and with verbal plural markers that are distinct from the nominal plural markers. There are four classes of verbs, based on the number and types of arguments that can occur in the verbal clause and how these arguments are marked (‘transitivity’). These are described in the section on verbs below.

The category ‘adjective’ is defined by its inherent ability to occur as a modifier of a noun. The category ‘adverb’ is defined by its inherent ability to occur as a modifier of clause. 

Hdi has the category ‘ideophone’, i.e., lexical items with a very limited distribution that usually characterize an auditory, visual, tactile, olfactory, or other sensory aspect of the event. There are very few ideophones in the dictionary, but it is likely that there are more members of this class that have not been recorded. 

Many nouns and verbs, and some adjectives, have been borrowed from languages with which Hdi speakers have direct or indirect contact. The most frequent are borrowings from Fula, marked F, and Hausa, marked H, followed by Arabic, marked Ar. Arabic borrowings came into Hdi indirectly, either through Fula or Hausa. There are also a number of borrowings from French, marked Fr or left unmarked, if obvious. 

<h2 id="The structure of the noun phrase">The structure of the noun phrase</h2>

A noun phrase is a phrase whose head is a noun. In many cases a noun phrase can be replaced by the head alone. The modifier within the noun phrase may precede or follow the head. Quantifiers precede the head. Determiners may precede the head, follow the head, or precede and follow the head within the same phrase. Some nouns are derived from verbs. 

<h3 id="Nominal number">Nominal number</h3>

Nouns can take a number of suffixes. The unmarked form of the noun has no number value. There are three plural suffixes: _-xà_, the less frequent _-ì_, and the rare suffix _-à_, which is combined with the infix _-a-_. The plural suffix does not have to be used if plurality is marked by some other means, e.g. by the quantifier ‘many’. This provides evidence that the unmarked form of the noun has no number value. The language has an associative plural construction consisting of the form _ì_ preceding a noun:

<table><tbody>
<tr><td><strong>
    (9)
</strong></td><td class="object-language" colspan="5"><em>ì krì ndá pákáw-á ghúvì</em></td></tr>
<tr><td></td><td class="morpheme">ì</td><td class="morpheme">krì</td><td class="morpheme">ndá</td><td class="morpheme">pákáw-á</td><td class="morpheme">ghúvì</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">ASSC.PL</span></td><td class="gloss">dog</td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">leopard-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">feces</td></tr>
<tr><td></td><td class="translation" colspan="5">'Dog and Hyena (lit. leopard feces)'</td></tr>
</tbody></table>

Hdi also has a collective marker _lá_, which precedes the noun and codes the group of people designated by the noun:

<table><tbody>
<tr><td><strong>
    (10)
</strong></td><td class="object-language" colspan="2"><em>lá	də́blə́m</em></td></tr>
<tr><td></td><td class="morpheme">lá</td><td class="morpheme">də́blə́m</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">COLL</span></td><td class="gloss">proper name</td></tr>
<tr><td></td><td class="translation" colspan="2">'the Diblim people'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (11)
</strong></td><td class="object-language" colspan="3"><em>lá m̀ndə́ rxá</em></td></tr>
<tr><td></td><td class="morpheme">lá</td><td class="morpheme">m̀ndə́</td><td class="morpheme">́rxá</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">COLL</span></td><td class="gloss">man</td><td class="gloss">wise</td></tr>
<tr><td></td><td class="translation" colspan="3">'wise people'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (12)
</strong></td><td class="object-language" colspan="2"><em>lá rvèrì</em></td></tr>
<tr><td></td><td class="morpheme">lá</td><td class="morpheme">rvèrì</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">COLL</span></td><td class="gloss">king</td></tr>
<tr><td></td><td class="translation" colspan="2">'kings' (the term <em>rvèrì</em> also means ‘lion’, but the form with <em>lá</em> indicates ‘kings’)</td></tr>
</tbody></table>
<h3 id="Modification of the noun">Modification of the noun</h3>
<h4 id="Modification through the genitive marker &lt;em&gt;á&lt;/em&gt;">Modification through the genitive marker <em>á</em></h4>

A modifying construction in which another noun or pronoun modifies the head noun (‘genitive construction’) has the form Noun-_á_ Noun/Pro, where the form _á_, glossed as GEN, is identical with one of the deictic-demonstrative markers:

<table><tbody>
<tr><td><strong>
    (13)
</strong></td><td class="object-language" colspan="2"><em>vú-á m̀ták	→	[vwám̀ták]</em></td></tr>
<tr><td></td><td class="morpheme">vú-á</td><td class="morpheme">m̀ták</td></tr>
<tr><td></td><td class="gloss">fire-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">bush</td></tr>
<tr><td></td><td class="translation" colspan="2">'bush fire'</td></tr>
</tbody></table>

Color terms belong to the class of nouns, and modification by a color term has the same form as modification by another noun:

<table><tbody>
<tr><td><strong>
    (14)
</strong></td><td class="object-language" colspan="2"><em>gù-á ngrá</em></td></tr>
<tr><td></td><td class="morpheme">gù-á</td><td class="morpheme">ngrá</td></tr>
<tr><td></td><td class="gloss">goat-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">black</td></tr>
<tr><td></td><td class="translation" colspan="2">'a black goat'</td></tr>
</tbody></table>

Modifying pronouns (‘possessive pronouns’) follow the genitive marker:

<table><tbody>
<tr><td><strong>
    (15)
</strong></td><td class="object-language" colspan="1"><em>zwán-á-ní	[zwángání]</em></td></tr>
<tr><td></td><td class="morpheme">zwán-á-ní</td></tr>
<tr><td></td><td class="gloss">child-<span style="font-variant: small-caps;">GEN-3SG</span></td></tr>
<tr><td></td><td class="translation" colspan="1">'his child'</td></tr>
</tbody></table>
<table class="table table-bordered">
<caption>Table 8: Possessive pronouns</caption>
<thead>
<tr>
<th>Person</th>
<th>Singular</th>
<th>Dual</th>
<th>Plural</th>
</tr>
</thead>
<tbody>
<tr>
<td>First</td>
<td>ɗá</td>
<td>úú</td>
<td>mú (incl); ŋní (excl)</td>
</tr>
<tr>
<td>Second</td>
<td>ghá</td>
<td></td>
<td>Ghúní</td>
</tr>
<tr>
<td>Third</td>
<td>Ní</td>
<td></td>
<td>tán/tàn</td>
</tr>
</tbody>
</table>

  

Some kinship terms, e.g. ‘mother’, ‘wife’, and ‘husband’, require the use of plural rather than singular possessive pronouns even if the intended possessor is singular. The use of plural rather than singular possessive pronouns is motivated by the roles the referents of these terms play within the family. 

The modifying construction can have the order modifier-head, with the genitive marker _á_ following the modifier. The modifiers in this construction all belong to the class of property concepts (concepts expressed by adjectives in many languages):

<table><tbody>
<tr><td><strong>
    (16)
</strong></td><td class="object-language" colspan="2"><em>lfíd-á	lgùt</em></td></tr>
<tr><td></td><td class="morpheme">lfíd-á</td><td class="morpheme">lgùt</td></tr>
<tr><td></td><td class="gloss">new-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">cloth</td></tr>
<tr><td></td><td class="translation" colspan="2">'new clothes'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (17)
</strong></td><td class="object-language" colspan="6"><em>índà ghwáɗàk-á skwì mà xgá yà</em></td></tr>
<tr><td></td><td class="morpheme">índà</td><td class="morpheme">ghwáɗàk-á</td><td class="morpheme">skwì</td><td class="morpheme">mà</td><td class="morpheme">xgá</td><td class="morpheme">yà</td></tr>
<tr><td></td><td class="gloss">all</td><td class="gloss">bad-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">thing</td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">home</td><td class="gloss"><span style="font-variant: small-caps;">COP</span></td></tr>
<tr><td></td><td class="translation" colspan="6">'that is all bad things at home'</td></tr>
</tbody></table>
<h4 id="Modification through the preposition &lt;em&gt;nà&lt;/em&gt;">Modification through the preposition <em>nà</em></h4>

The construction Noun _nà_ Noun is used only in a few fixed expressions referring to domestic animals. The form _nà_ is related to the proximate demonstrative _ná_:

<table><tbody>
<tr><td><strong>
    (18)
</strong></td><td class="object-language" colspan="3"><em>má nà gù</em></td></tr>
<tr><td></td><td class="morpheme">má</td><td class="morpheme">nà</td><td class="morpheme">gù</td></tr>
<tr><td></td><td class="gloss">mother</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">goat</td></tr>
<tr><td></td><td class="translation" colspan="3">'a female goat' (not 'mother of a goat')</td></tr>
</tbody></table>
<h4 id="Modification through the preposition &lt;em&gt;ngá&lt;/em&gt;">Modification through the preposition <em>ngá</em></h4>

The modification relationship between two nominal expressions may also be coded through the preposition _ngá_ (glossed as FOR) in the construction Noun _ngá_ Noun. In most cases, this construction is used where the modifier is the intended owner or destination of the head:

<table><tbody>
<tr><td><strong>
    (19)
</strong></td><td class="object-language" colspan="2"><em>ùvá ngá-ɗá</em></td></tr>
<tr><td></td><td class="morpheme">ùvá</td><td class="morpheme">ngá-ɗá</td></tr>
<tr><td></td><td class="gloss">cat</td><td class="gloss"><span style="font-variant: small-caps;">FOR-1SG</span></td></tr>
<tr><td></td><td class="translation" colspan="2">'the cat for me'</td></tr>
</tbody></table>

Nouns followed by the preposition _ngá_ must have high tone, regardless of their underlying tones. Thus _hlà_ ‘cow’, _gù_ ‘goat’, and _krì_ ‘dog’ all have high tone before _ngá_:

<table><tbody>
<tr><td><strong>
    (20)
</strong></td><td class="object-language" colspan="2"><em>hlá ngá-ní</em></td></tr>
<tr><td></td><td class="morpheme">hlá</td><td class="morpheme">ngá-ní</td></tr>
<tr><td></td><td class="gloss">cow</td><td class="gloss"><span style="font-variant: small-caps;">FOR-3SG</span></td></tr>
<tr><td></td><td class="translation" colspan="2">'the cow is for him'</td></tr>
</tbody></table>
<h4 id="Modification through the comment marker &lt;em&gt;tá&lt;/em&gt;">Modification through the comment marker <em>tá</em></h4>

The modifying construction Noun _tá_ Noun codes an attribute of the head. The form _tá_ functions as the comment marker in a variety of constructions, hence it is glossed COM for ‘comment marker’:

<table><tbody>
<tr><td><strong>
    (21)
</strong></td><td class="object-language" colspan="5"><em>mtá tá dá-ní mà m̀ndú</em></td></tr>
<tr><td></td><td class="morpheme">mtá</td><td class="morpheme">tá</td><td class="morpheme">dá-ní</td><td class="morpheme">mà</td><td class="morpheme">m̀ndú</td></tr>
<tr><td></td><td class="gloss">death</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">father-<span style="font-variant: small-caps;">3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">man</td></tr>
<tr><td></td><td class="translation" colspan="5">'death of the man's father'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (22)
</strong></td><td class="object-language" colspan="7"><em>glá tá zwán tà	kúm-ày tá màrà-n-tà . . . </em></td></tr>
<tr><td></td><td class="morpheme">glá</td><td class="morpheme">tá</td><td class="morpheme">zwán</td><td class="morpheme">tà</td><td class="morpheme">kúm-ày</td><td class="morpheme">tá</td><td class="morpheme">màrà-n-tà</td></tr>
<tr><td></td><td class="gloss">grow</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">child</td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">want-<span style="font-variant: small-caps;">PO</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">show-<span style="font-variant: small-caps;">3-REF</span></td></tr>
<tr><td></td><td class="translation" colspan="7">'the child's growth will show . . .'</td></tr>
</tbody></table>

The construction Noun _tá_ Noun can be used for ethnonyms when the head of the construction, the first noun, refers to a female. Forms with _tá_ can be replaced in many cases by forms with the genitive _-á_:

<table><tbody>
<tr><td><strong>
    (23)
</strong></td><td class="object-language" colspan="3"><em>mákwà tá xdí</em></td></tr>
<tr><td></td><td class="morpheme">mákwà</td><td class="morpheme">tá</td><td class="morpheme">xdí</td></tr>
<tr><td></td><td class="gloss">girl</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">Hdi</td></tr>
<tr><td></td><td class="translation" colspan="3">'a Hdi girl'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (24)
</strong></td><td class="object-language" colspan="2"><em>mákw-á xdí</em></td></tr>
<tr><td></td><td class="morpheme">mákw-á</td><td class="morpheme">xdí</td></tr>
<tr><td></td><td class="gloss">girl-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">Hdi</td></tr>
<tr><td></td><td class="translation" colspan="2">'a Hdi girl'</td></tr>
</tbody></table>
<h4 id="Coding the notion of belonging">Coding the notion of belonging</h4>

There exists a construction having the form Possessum-Genitive-Pronoun _mà_ Possessor, where the pronoun codes the features of person and number of the possessor. The form _mà_ is identical with the preposition meaning ‘within’. The construction is used only when both components, the possessor and the possessum, are nominal. The function of the construction is different from the one involving genitive modification and different from modification through the preposition _tá_:

<table><tbody>
<tr><td><strong>
    (25)
</strong></td><td class="object-language" colspan="3"><em>kr-à-ní mà m̀ndú/mbítsá</em></td></tr>
<tr><td></td><td class="morpheme">kr-à-ní</td><td class="morpheme">mà</td><td class="morpheme">m̀ndú/mbítsá</td></tr>
<tr><td></td><td class="gloss">dog-<span style="font-variant: small-caps;">GEN-3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">man/Mbitsa</td></tr>
<tr><td></td><td class="translation" colspan="3">'a dog belonging to a man/Mbitsa'</td></tr>
</tbody></table>

The construction is used for coding the parent-child relationship, but not the child-parent relationship or a spousal relationship:

<table><tbody>
<tr><td><strong>
    (26)
</strong></td><td class="object-language" colspan="3"><em>dá-ní mà mbítsá</em></td></tr>
<tr><td></td><td class="morpheme">dá-ní</td><td class="morpheme">mà</td><td class="morpheme">mbítsá</td></tr>
<tr><td></td><td class="gloss">father-<span style="font-variant: small-caps;">3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">Mbitsa</td></tr>
<tr><td></td><td class="translation" colspan="3">'Mbitsa's father'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (27)
</strong></td><td class="object-language" colspan="3"><em>dá-tán mà zwán-ì</em></td></tr>
<tr><td></td><td class="morpheme">dá-tán</td><td class="morpheme">mà</td><td class="morpheme">zwán-ì</td></tr>
<tr><td></td><td class="gloss">father-<span style="font-variant: small-caps;">3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">child-<span style="font-variant: small-caps;">PL</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'children's father'</td></tr>
</tbody></table>

For the child-parent relationship or spousal relationship the genitive marker _-á_ is used:

<table><tbody>
<tr><td><strong>
    (28)
</strong></td><td class="object-language" colspan="2"><em>zwán-á	m̀ndú</em></td></tr>
<tr><td></td><td class="morpheme">zwán-á</td><td class="morpheme">m̀ndú</td></tr>
<tr><td></td><td class="gloss">child-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">man</td></tr>
<tr><td></td><td class="translation" colspan="2">'man's child'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (29)
</strong></td><td class="object-language" colspan="2"><em>màrkw-á m̀ndú</em></td></tr>
<tr><td></td><td class="morpheme">màrkw-á</td><td class="morpheme">m̀ndú</td></tr>
<tr><td></td><td class="gloss">woman-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">man</td></tr>
<tr><td></td><td class="translation" colspan="2">'man's wife'</td></tr>
</tbody></table>
<h4 id="Modification of nouns by adjectives">Modification of nouns by adjectives</h4>

A lexical item is an adjective in Hdi if (1) it modifies nouns and (2) it cannot be used as an argument. Terms for size, shape, and quality are adjectives in Hdi; color terms are not.

The group of adjectives includes the following (an exhaustive list of items found in our data): _dágálá_ ‘large’, _kítìkw_ ‘small’, _kì’yá_ ‘small’, _xɓùzá_ ‘big-bellied’, _slùxá_ ‘oval’, _tùmbùzlá_ ‘round’, _tə̀ntə̀ngá_ ‘hard’, _ìná_ ‘good’, ‘beautiful’, ‘pretty’. The modifying construction with adjectives has the form Noun Adjective, without any intervening marker. Inherent adjectives in the attributive function occur after the noun they modify:

<table><tbody>
<tr><td><strong>
    (30)
</strong></td><td class="object-language" colspan="2"><em>vú kì’yá</em></td></tr>
<tr><td></td><td class="morpheme">vú</td><td class="morpheme">kì’yá</td></tr>
<tr><td></td><td class="gloss">fire</td><td class="gloss">small</td></tr>
<tr><td></td><td class="translation" colspan="2">'small fire'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (31)
</strong></td><td class="object-language" colspan="2"><em>xvá kwítìk</em></td></tr>
<tr><td></td><td class="morpheme">xvá</td><td class="morpheme">kwítìk</td></tr>
<tr><td></td><td class="gloss">work</td><td class="gloss">little</td></tr>
<tr><td></td><td class="translation" colspan="2">'small work'</td></tr>
</tbody></table>

Numerals behave like adjectives in that the modifying construction has the form Head Numeral, without any additional markers:

<table><tbody>
<tr><td><strong>
    (32)
</strong></td><td class="object-language" colspan="2"><em>skwì	tùrtúkw</em></td></tr>
<tr><td></td><td class="morpheme">skwì</td><td class="morpheme">tùrtúkw</td></tr>
<tr><td></td><td class="gloss">thing</td><td class="gloss">one</td></tr>
<tr><td></td><td class="translation" colspan="2">'one thing'</td></tr>
</tbody></table>
<h4 id="The comparative form of the modifying construction">The comparative form of the modifying construction</h4>

Modifying constructions with adjectives code only two degrees: the unmarked and the comparative, where the latter corresponds in scope to the English comparative and superlative. A comparative modifying construction is formed by the use of the copula _yà_ following the head noun and preceding the adjective:

<table><tbody>
<tr><td><strong>
    (33)
</strong></td><td class="object-language" colspan="3"><em>m̀ndú yà dágálá</em></td></tr>
<tr><td></td><td class="morpheme">m̀ndú</td><td class="morpheme">yà</td><td class="morpheme">dágálá</td></tr>
<tr><td></td><td class="gloss">man</td><td class="gloss"><span style="font-variant: small-caps;">COP</span></td><td class="gloss">important</td></tr>
<tr><td></td><td class="translation" colspan="3">'the most important man'</td></tr>
</tbody></table>

Cf.:

<table><tbody>
<tr><td><strong>
    (34)
</strong></td><td class="object-language" colspan="2"><em>m̀ndú dágálá</em></td></tr>
<tr><td></td><td class="morpheme">m̀ndú</td><td class="morpheme">dágálá</td></tr>
<tr><td></td><td class="gloss">man</td><td class="gloss">important</td></tr>
<tr><td></td><td class="translation" colspan="2">'an important man'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (35)
</strong></td><td class="object-language" colspan="3"><em>m̀ndú yà kítìkw</em></td></tr>
<tr><td></td><td class="morpheme">m̀ndú</td><td class="morpheme">yà</td><td class="morpheme">kítìkw</td></tr>
<tr><td></td><td class="gloss">man</td><td class="gloss"><span style="font-variant: small-caps;">COP</span></td><td class="gloss">small</td></tr>
<tr><td></td><td class="translation" colspan="3">'the smallest man'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (36)
</strong></td><td class="object-language" colspan="3"><em>m̀ndú yà ndáxíɗá</em></td></tr>
<tr><td></td><td class="morpheme">m̀ndú</td><td class="morpheme">yà</td><td class="morpheme">ndáxíɗá</td></tr>
<tr><td></td><td class="gloss">man</td><td class="gloss"><span style="font-variant: small-caps;">COP</span></td><td class="gloss">wisdom</td></tr>
<tr><td></td><td class="translation" colspan="3">'the wisest man'</td></tr>
</tbody></table>
<h4 id="Modification through ordinal numerals">Modification through ordinal numerals</h4>

Modification through ordinal numerals has the form _má_ Numeral-Genitive Noun:

<table><tbody>
<tr><td><strong>
    (37)
</strong></td><td class="object-language" colspan="3"><em>má xìs-á màrkwá-tán</em></td></tr>
<tr><td></td><td class="morpheme">má</td><td class="morpheme">xìs-á</td><td class="morpheme">màrkwá-tán</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">second-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">wife-<span style="font-variant: small-caps;">3PL</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'their second wife'</td></tr>
</tbody></table>
<h4 id="Noun modified by a quantifier">Noun modified by a quantifier</h4>

Quantifiers include the same lexical items that function as adjectives: _tùrtúkw_ ‘one, alone’, _dágálá_ ‘many’, _kítìkw_ ‘a little’, _kí’yá_ ‘some, little’, _dímdím_ or _démdém_ ‘a lot’, and possibly several others. Modification by quantifiers has the form Noun Quantifier. Other material, such as a possessive pronoun, may intervene between the noun and the quantifier. Quantifiers do not occur with deictics:

<table><tbody>
<tr><td><strong>
    (38)
</strong></td><td class="object-language" colspan="4"><em>skw-í-p-skwà tá ù’wà kì’yá</em></td></tr>
<tr><td></td><td class="morpheme">skw-í-p-skwà</td><td class="morpheme">tá</td><td class="morpheme">ù’wà</td><td class="morpheme">kì’yá</td></tr>
<tr><td></td><td class="gloss">buy-<span style="font-variant: small-caps;">1SG-OUT</span>-buy</td><td class="gloss">second-<span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">milk</td><td class="gloss">little</td></tr>
<tr><td></td><td class="translation" colspan="4">'she sold me some milk'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (39)
</strong></td><td class="object-language" colspan="4"><em>s-ù-sà tá ghzú	démdém</em></td></tr>
<tr><td></td><td class="morpheme">s-ù-sà</td><td class="morpheme">tá</td><td class="morpheme">ghzú</td><td class="morpheme">démdém</td></tr>
<tr><td></td><td class="gloss">drink-<span style="font-variant: small-caps;">SO</span>-drink</td><td class="gloss">second-<span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">beer</td><td class="gloss">all</td></tr>
<tr><td></td><td class="translation" colspan="4">'she drank all of the beer'</td></tr>
</tbody></table>
<h4 id="The associative phrase">The associative phrase</h4>

The term ‘associative phrase’ refers to the structure Noun Phrase _ndá_ Noun Phrase. These structures encompass the functions of associative and coordinating conjunctions, corresponding to “Noun and Noun” and “Noun with Noun” in English.

<h4 id="Nouns in associative phrases">Nouns in associative phrases</h4>

Nouns are conjoined in associative phrases by the associative preposition _ndá_. If the components of an associative phrase are human, the associative phrase must be preceded by the associative plural _ì_:

<table><tbody>
<tr><td><strong>
    (40)
</strong></td><td class="object-language" colspan="8"><em>kà zə̀ ì kɗérì	ndá zwànànì tá m̀ghám</em></td></tr>
<tr><td></td><td class="morpheme">kà</td><td class="morpheme">zə</td><td class="morpheme">ì</td><td class="morpheme">kɗérì</td><td class="morpheme">ndá</td><td class="morpheme">zwànànì</td><td class="morpheme">tá</td><td class="morpheme">m̀ghám</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">live</td><td class="gloss"><span style="font-variant: small-caps;">ASSC:PL</span></td><td class="gloss">Kderi</td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">child:<span style="font-variant: small-caps;">PL</span>-GEN-3SG</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">chief</td></tr>
<tr><td></td><td class="translation" colspan="8">'And Kderi and his children lived happily (lit. 'royally')'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (41)
</strong></td><td class="object-language" colspan="7"><em>áyà tá	ì gùlú ndá zírí ndá . . .</em></td></tr>
<tr><td></td><td class="morpheme">àyá</td><td class="morpheme">tá</td><td class="morpheme">ì</td><td class="morpheme">gùlú</td><td class="morpheme">ndá</td><td class="morpheme">zírí</td><td class="morpheme">ndá</td></tr>
<tr><td></td><td class="gloss">give.birth</td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC:PL</span></td><td class="gloss">Gulu</td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">Ziri</td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td></tr>
<tr><td></td><td class="translation" colspan="7">'and he begot Gulu and Ziri and...'</td></tr>
</tbody></table>

In a list of two or more nouns, the associative marker occurs only before the last noun:

<table><tbody>
<tr><td><strong>
    (42)
</strong></td><td class="object-language" colspan="11"><em>zívr-á xdí zàmàn-à gà xdí ndá m̀ghám-á wúyá skwì gà xdí</em></td></tr>
<tr><td></td><td class="morpheme">zívr-á</td><td class="morpheme">xdí</td><td class="morpheme">zàmàn-à</td><td class="morpheme">gà</td><td class="morpheme">xdí</td><td class="morpheme">ndá</td><td class="morpheme">m̀ghám-á</td><td class="morpheme">wúyá</td><td class="morpheme">skwì</td><td class="morpheme">gà</td><td class="morpheme">xdí</td></tr>
<tr><td></td><td class="gloss">origing-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">Hdi</td><td class="gloss">civilization-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">Hdi</td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">chief-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">festical</td><td class="gloss">thing</td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">Hdi</td></tr>
<tr><td></td><td class="translation" colspan="11">'origin of Hdi, civilization of Hdi, and the main festival of Hdi'</td></tr>
</tbody></table>
<h4 id="Pronouns in associative phrases">Pronouns in associative phrases</h4>

If the first member of the associative phrase is represented by a pronoun, the pronoun is plural even if the first participant is singular. Thus, instead of the third person singular pronoun, the third-person plural must be used, and instead of the first-person singular, the first-person plural must be used. 

<table><tbody>
<tr><td><strong>
    (43)
</strong></td><td class="object-language" colspan="7"><em>mbàɗ ká máyá kà rwá-xə̀n ndá zwànà-ní</em></td></tr>
<tr><td></td><td class="morpheme">mbàɗ</td><td class="morpheme">ká</td><td class="morpheme">máyá</td><td class="morpheme">kà</td><td class="morpheme">rwá-xə̀n</td><td class="morpheme">ndá</td><td class="morpheme">zwànà-ní</td></tr>
<tr><td></td><td class="gloss">then</td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">hunger</td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">threaten-<span style="font-variant: small-caps;">3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">child:PL:GEN-<span style="font-variant: small-caps;">3SG</span></td></tr>
<tr><td></td><td class="translation" colspan="7">'then hunger threatened him and his children (lit. 'them and his children')'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (44)
</strong></td><td class="object-language" colspan="7"><em>áŋní ndá zwàn-à-ɗá tà rwá-kú dà máyá</em></td></tr>
<tr><td></td><td class="morpheme">áŋní</td><td class="morpheme">ndá</td><td class="morpheme">zwàn-à-ɗá</td><td class="morpheme">tà</td><td class="morpheme">rwá-kú</td><td class="morpheme">dà</td><td class="morpheme">máyá</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">1PL.INCL</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">child:PL-<span style="font-variant: small-caps;">GEN-1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">threat-<span style="font-variant: small-caps;">ABS</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">hunger</td></tr>
<tr><td></td><td class="translation" colspan="7">'I and my children are suffering from hunger (lit. 'we and my children')'</td></tr>
</tbody></table>
<h2 id="Reference Systems">Reference Systems</h2>
<h3 id="The coding means">The coding means</h3>

The coding means within the reference system are: overt mention of the noun; subject and object independent and suffixed pronouns; deictics; the anaphor _tsá_, which is glossed in Frajzyngier with Shay 2002 as DEF but which refers to previously mentioned nouns; and several determiners which can precede, follow, or both precede and follow the noun. The following chart lists the independent pronouns:

  

<table class="table table-bordered">
<caption>Table 9: Independent pronouns</caption>
<thead>
<tr>
<th>Person</th>
<th>Singular</th>
<th>Dual</th>
<th>Plural</th>
</tr>
</thead>
<tbody>
<tr>
<td>First</td>
<td>ɗá</td>
<td>úú</td>
<td>ámú (incl); áŋní (excl)</td>
</tr>
<tr>
<td>Second</td>
<td>kághá</td>
<td></td>
<td>kághúní</td>
</tr>
<tr>
<td>Third</td>
<td>tsátsí</td>
<td></td>
<td>xáxə̀n</td>
</tr>
</tbody>
</table>

  

The unspecified human object is marked by the noun _m̀ndú_ ‘man’ preceded by the comment marker _tá_: 

<table><tbody>
<tr><td><strong>
    (45)
</strong></td><td class="object-language" colspan="4"><em>hlìglá-hlìglá xwáyá tá mndú </em></td></tr>
<tr><td></td><td class="morpheme">hlìglá-hlìglá</td><td class="morpheme">xwáyá</td><td class="morpheme">tá</td><td class="morpheme">mndú</td></tr>
<tr><td></td><td class="gloss">stab-stab</td><td class="gloss">Hoya</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">man</td></tr>
<tr><td></td><td class="translation" colspan="4">'Hoya stabbed somebody'</td></tr>
</tbody></table>

The complete range of functions of the combinations of various coding means within the system of reference has yet to be discovered. 

<h3 id="Deixis">Deixis</h3>

There is a three-way distinction within the deictic system, coding three degrees of distance with respect to the speaker: _á_ ‘remote’, _yá_ ‘middle distance’, and _ná_ ‘proximate’. The reduplicated deictic form can be used as an independent noun in a clause:

<table><tbody>
<tr><td><strong>
    (46)
</strong></td><td class="object-language" colspan="3"><em>bà-f-b-í tá yá-yá</em></td></tr>
<tr><td></td><td class="morpheme">bà-f-b-í</td><td class="morpheme">tá</td><td class="morpheme">yá-yá</td></tr>
<tr><td></td><td class="gloss">build-<span style="font-variant: small-caps;">UP</span>-build-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM-DEM</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'I built that'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (47)
</strong></td><td class="object-language" colspan="3"><em>bà-f-b-í tá ná-ná</em></td></tr>
<tr><td></td><td class="morpheme">bà-f-b-í</td><td class="morpheme">tá</td><td class="morpheme">ná-ná</td></tr>
<tr><td></td><td class="gloss">build-<span style="font-variant: small-caps;">UP</span>-build-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM-DEM</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'I built this'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (48)
</strong></td><td class="object-language" colspan="3"><em>bà-f-b-í tá á-á</em></td></tr>
<tr><td></td><td class="morpheme">bà-f-b-í</td><td class="morpheme">tá</td><td class="morpheme">á-á</td></tr>
<tr><td></td><td class="gloss">build-<span style="font-variant: small-caps;">UP</span>-build-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM-DEM</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'I built that thing over there'</td></tr>
</tbody></table>

When deictics function as determiners they can precede and/or follow the head noun. Moreover, they can be reduplicated in the position before and/or after the noun:

<table><tbody>
<tr><td><strong>
    (49)
</strong></td><td class="object-language" colspan="4"><em>yà yá mákwà yá</em></td></tr>
<tr><td></td><td class="morpheme">yà</td><td class="morpheme">yá</td><td class="morpheme">mákwà</td><td class="morpheme">yá</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">girl</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td></tr>
<tr><td></td><td class="translation" colspan="4">'this girl' (the girl must be visible)</td></tr>
</tbody></table>

If there is only one demonstrative before the noun, the distance seems to be closer than if there are two demonstratives before the noun:

<table><tbody>
<tr><td><strong>
    (50)
</strong></td><td class="object-language" colspan="3"><em>yá mákwà yá</em></td></tr>
<tr><td></td><td class="morpheme">yá</td><td class="morpheme">mákwà</td><td class="morpheme">yá</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">girl</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'this girl' (closer distance; must be visible)</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (51)
</strong></td><td class="object-language" colspan="4"><em>à á mákwà á</em></td></tr>
<tr><td></td><td class="morpheme">à</td><td class="morpheme">á</td><td class="morpheme">mákwà</td><td class="morpheme">á</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">girl</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td></tr>
<tr><td></td><td class="translation" colspan="4">'that girl'</td></tr>
</tbody></table>

Neither demonstratives nor deictic markers code a number distinction. 

<h3 id="Anaphora">Anaphora</h3>

Previous mention is marked by the form _tsá_, glossed in Frajzyngier with Shay as DEF, alone or with any combination of deictic markers. The anaphor _tsá_ can be the only component of the noun phrase:

<table><tbody>
<tr><td><strong>
    (52)
</strong></td><td class="object-language" colspan="7"><em>tà xúlá tsá ngá xgà-f-tá xgà ghúní . . .</em></td></tr>
<tr><td></td><td class="morpheme">tà</td><td class="morpheme">xúlá</td><td class="morpheme">tsá</td><td class="morpheme">ngá</td><td class="morpheme">xgà-f-tá</td><td class="morpheme">xgà</td><td class="morpheme">ghúní</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">back</td><td class="gloss"><span style="font-variant: small-caps;">DEF</span></td><td class="gloss"><span style="font-variant: small-caps;">NORM</span></td><td class="gloss">call-<span style="font-variant: small-caps;">UP-REF</span></td><td class="gloss">call</td><td class="gloss"><span style="font-variant: small-caps;">2PL</span></td></tr>
<tr><td></td><td class="translation" colspan="7">'afterwards, they would call you up . . .'</td></tr>
</tbody></table>

The anaphor can also co-occur with a deictic marker that functions as the sole component of the noun phrase, or it can occur as the determiner of the noun. Both cases are illustrated in the next example:

<table><tbody>
<tr><td><strong>
    (53)
</strong></td><td class="object-language" colspan="11"><em>dàgà bàɗ tsá yá dzà’á ghlrá-f-tà tsá m̀ndú yá tá wúyá</em></td></tr>
<tr><td></td><td class="morpheme">dàgà</td><td class="morpheme">bàɗ</td><td class="morpheme">tsá</td><td class="morpheme">yá</td><td class="morpheme">dzà’á</td><td class="morpheme">ghlrá-f-tà</td><td class="morpheme">tsá</td><td class="morpheme">m̀ndú</td><td class="morpheme">yá</td><td class="morpheme">tá</td><td class="morpheme">wúyá</td></tr>
<tr><td></td><td class="gloss">from</td><td class="gloss">day</td><td class="gloss"><span style="font-variant: small-caps;">DEF</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">FUT</span></td><td class="gloss">perform-<span style="font-variant: small-caps;">UP-REF</span></td><td class="gloss"><span style="font-variant: small-caps;">DEF</span></td><td class="gloss">man</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">rites</td></tr>
<tr><td></td><td class="translation" colspan="11">'from that day on the man will perform the rites'</td></tr>
</tbody></table>
<h3 id="Referentiality of event">Referentiality of event</h3>

Hdi has the functional domain of referentiality of the event, where the distinction is between referential (marked) and non-referential (unmarked) events. Referentiality of the event is marked by the suffix _-ta_ with high or low tone, glossed as REF, added to the verb.

The marker _-ta_ indicates that the proposition refers to real-world phenomena. The event is made referential if it affects a referential object or a referential predicate. Compare the unspecified object versus the previously mentioned object:

<table><tbody>
<tr><td><strong>
    (54)
</strong></td><td class="object-language" colspan="6"><em>xìyá (ná) xàɗ-ká tà dzáw-áy wà</em></td></tr>
<tr><td></td><td class="morpheme">xìyá</td><td class="morpheme">(ná)</td><td class="morpheme">xàɗ-ká</td><td class="morpheme">tà</td><td class="morpheme">dzáw-áy</td><td class="morpheme">wà</td></tr>
<tr><td></td><td class="gloss">guinea corn</td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">lack-<span style="font-variant: small-caps;">2SG</span></td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">trade:PL-<span style="font-variant: small-caps;">PO</span></td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td></tr>
<tr><td></td><td class="translation" colspan="6">'Guinea corn, you do not sell!'</td></tr>
</tbody></table>

If the object is referential due to previous mention in discourse or presence in the environment of speech, the verb has the suffix _-tá_:

<table><tbody>
<tr><td><strong>
    (55)
</strong></td><td class="object-language" colspan="8"><em>tsá xìyá yá ná xàɗ-ká tà dzáwá-tà wà</em></td></tr>
<tr><td></td><td class="morpheme">tsá</td><td class="morpheme">xìyá</td><td class="morpheme">yá</td><td class="morpheme">ná</td><td class="morpheme">xàɗ-ká</td><td class="morpheme">tà</td><td class="morpheme">dzáwá-tà</td><td class="morpheme">wà</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">DEF</span></td><td class="gloss">guinea corn</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">lack-<span style="font-variant: small-caps;">2SG</span></td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">trade:PL-<span style="font-variant: small-caps;">REF</span></td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td></tr>
<tr><td></td><td class="translation" colspan="8">'the guinea corn [previously mentioned], you do not sell'</td></tr>
</tbody></table>
<h2 id="Verbless Clauses">Verbless Clauses</h2>

The term ‘verbless clause’ refers to the formal property of not having a verbal predicate. The verbless clauses include: equational predication; identificational predication; attributive predication; possessive predication; existential predication; locative stative predication; and presentative predication. 

<h3 id="Equational clauses">Equational clauses</h3>

Equational clauses identify one noun phrase by another. Equational clauses in Hdi have no copula. The distinction between subject and predicate is marked through word order. The predicate is the first noun phrase and the subject is the noun phrase that follows:

<table><tbody>
<tr><td><strong>
    (56)
</strong></td><td class="object-language" colspan="3"><em>m̀nd-á ráyá mbítsá</em></td></tr>
<tr><td></td><td class="morpheme">m̀nd-á</td><td class="morpheme">ráyá</td><td class="morpheme">mbítsá</td></tr>
<tr><td></td><td class="gloss">man-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">hunt</td><td class="gloss">Mbitsa</td></tr>
<tr><td></td><td class="translation" colspan="3">'Mbitsa is a hunter'</td></tr>
</tbody></table>
<h3 id="Identificational clauses">Identificational clauses</h3>

An identificational clause is a clause whose subject has been mentioned in the previous discourse or has been present in the discourse environment but is not overtly marked in the clause. Such clauses have the form Noun phrase Copula, where the noun phrase is the predicate. The subject is not overtly marked. The copula could be any of the series of demonstratives, but with low rather than high tone: _à_, _nà_, or _yà_. The last tone of the noun must be high before the copula, regardless of the underlying tone of the noun. This is the same rule as the one that operates before subjects in verbal clauses. Thus, the low-tone _hlà_ ‘cow’ has high tone before a copula:

<table><tbody>
<tr><td><strong>
    (57)
</strong></td><td class="object-language" colspan="2"><em>hlá yà</em></td></tr>
<tr><td></td><td class="morpheme">hlá</td><td class="morpheme">yà</td></tr>
<tr><td></td><td class="gloss">cow</td><td class="gloss"><span style="font-variant: small-caps;">COP</span></td></tr>
<tr><td></td><td class="translation" colspan="2">'it is a cow'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (58)
</strong></td><td class="object-language" colspan="2"><em>twák yà/nà/à</em></td></tr>
<tr><td></td><td class="morpheme">twàk</td><td class="morpheme">yà/nà/à</td></tr>
<tr><td></td><td class="gloss">sheep</td><td class="gloss"><span style="font-variant: small-caps;">COP</span></td></tr>
<tr><td></td><td class="translation" colspan="2">'it is a sheep' (<em>twàk</em> 'sheep')</td></tr>
</tbody></table>
<h3 id="Attributive predication">Attributive predication</h3>

Attributive predication defines the attribute of the noun. Property-concept words, like noun phrases, are marked for the predicative function by the clause-initial position. There are two types of property concept expressions: inherent adjectives and expressions derived from other lexical categories. 

The order Predicate Noun is the pragmatically unmarked order. Thus the adjective _kítìkw_ ‘small’ ends in high tone before the subject:

<table><tbody>
<tr><td><strong>
    (59)
</strong></td><td class="object-language" colspan="2"><em>kítíkw	mbítsá</em></td></tr>
<tr><td></td><td class="morpheme">kítíkw</td><td class="morpheme">mbítsá</td></tr>
<tr><td></td><td class="gloss">small</td><td class="gloss">Mbitsa</td></tr>
<tr><td></td><td class="translation" colspan="2">'Mbitsa is small'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (60)
</strong></td><td class="object-language" colspan="4"><em>dágálá	yá m̀ndú yá</em></td></tr>
<tr><td></td><td class="morpheme">dágálá</td><td class="morpheme">yá</td><td class="morpheme">m̀ndú</td><td class="morpheme">yá</td></tr>
<tr><td></td><td class="gloss">big</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">man</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td></tr>
<tr><td></td><td class="translation" colspan="4">'that man is big'</td></tr>
</tbody></table>
<h3 id="Possessive predication">Possessive predication</h3>

The term ‘possessive predication’ refers to predications where the subject owns an entity. The possessive clause has the structure _ngá_-Possessor (Copula) Possessum:

<table><tbody>
<tr><td><strong>
    (61)
</strong></td><td class="object-language" colspan="4"><em>ngá-ghá à hlà á</em></td></tr>
<tr><td></td><td class="morpheme">ngá-ghá</td><td class="morpheme">à</td><td class="morpheme">hlà</td><td class="morpheme">á</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">FOR-2SG</span></td><td class="gloss"><span style="font-variant: small-caps;">COP</span></td><td class="gloss">cow</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td></tr>
<tr><td></td><td class="translation" colspan="4">'that cow over there is yours'</td></tr>
</tbody></table>
<h3 id="Existential predication">Existential predication</h3>

Existential predications are formed with the clause-initial predicate _màmú_ ‘exist’ followed by the subject of the clause and complements, if any:

<table><tbody>
<tr><td><strong>
    (62)
</strong></td><td class="object-language" colspan="7"><em>màmú sàn m̀ghám tá kl-áf-tá màràk xìs</em></td></tr>
<tr><td></td><td class="morpheme">màmú</td><td class="morpheme">sàn</td><td class="morpheme">m̀ghám</td><td class="morpheme">tá</td><td class="morpheme">kl-áf-tá</td><td class="morpheme">màràk</td><td class="morpheme">xìs</td></tr>
<tr><td></td><td class="gloss">exist</td><td class="gloss">certain</td><td class="gloss">chief</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">take-<span style="font-variant: small-caps;">UP-REF</span></td><td class="gloss">wife</td><td class="gloss">two</td></tr>
<tr><td></td><td class="translation" colspan="7">'there was a chief who married to wives'</td></tr>
</tbody></table>

The form _màmú_ may be reduced to _màá_:

<table><tbody>
<tr><td><strong>
    (63)
</strong></td><td class="object-language" colspan="2"><em>màá	skwì</em></td></tr>
<tr><td></td><td class="morpheme">màá</td><td class="morpheme">skwì</td></tr>
<tr><td></td><td class="gloss">exist</td><td class="gloss">thing</td></tr>
<tr><td></td><td class="translation" colspan="2">'there is a thing'</td></tr>
</tbody></table>
<h3 id="Locative predications of the type: X is located at Y">Locative predications of the type: X is located at Y</h3>

In locative predicative expressions, the locative phrase precedes the subject of the clause. The locative predication has the form Preposition Noun Noun. Prepositions may include _tà_ ‘at’, ‘in’; _mà_ ‘inside’; and _dà_ ‘in’; as well as the prepositional complex _mìstá_ ‘under’, ‘together’:

<table><tbody>
<tr><td><strong>
    (64)
</strong></td><td class="object-language" colspan="3"><em>tà zlə́ŋ dèrí</em></td></tr>
<tr><td></td><td class="morpheme">tà</td><td class="morpheme">zlə́ŋ</td><td class="morpheme">dèrí</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">bed</td><td class="gloss">hat</td></tr>
<tr><td></td><td class="translation" colspan="3">'the hat is on the bed'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (65)
</strong></td><td class="object-language" colspan="3"><em>mà zlə́ŋ dèrí</em></td></tr>
<tr><td></td><td class="morpheme">mà</td><td class="morpheme">zlə́ŋ</td><td class="morpheme">dèrí</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">bed</td><td class="gloss">hat</td></tr>
<tr><td></td><td class="translation" colspan="3">'the hat is inside the bed'</td></tr>
</tbody></table>
<h3 id="Presentative predication">Presentative predication</h3>

The presentative predication is formed with the clause-initial deictic particle _wá_ (PRES) followed by deictics coding the distance between the speaker and the referent. The form with the remote deictic _á_ may be used only when the subject is not in the same location as the speaker:

<table><tbody>
<tr><td><strong>
    (66)
</strong></td><td class="object-language" colspan="4"><em>wá á gà mókóló</em></td></tr>
<tr><td></td><td class="morpheme">wá</td><td class="morpheme">á</td><td class="morpheme">gà</td><td class="morpheme">mókóló</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">PRES</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">PREP</td><td class="gloss">Mokolo</td></tr>
<tr><td></td><td class="translation" colspan="4">'he is in Mokolo'(The speaker is not in Mokolo.)</td></tr>
</tbody></table>

The form with ná may be used only if the speaker is in the same location as the subject:

<table><tbody>
<tr><td><strong>
    (67)
</strong></td><td class="object-language" colspan="4"><em>wá ná gà mókóló</em></td></tr>
<tr><td></td><td class="morpheme">wá</td><td class="morpheme">ná</td><td class="morpheme">gà</td><td class="morpheme">mókóló</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">PRES</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">PREP</td><td class="gloss">Mokolo</td></tr>
<tr><td></td><td class="translation" colspan="4">'he is in Mokolo'(The speaker is in Mokolo.)</td></tr>
</tbody></table>
<h2 id="Verbal Clauses">Verbal Clauses</h2>

The formal means deployed in verbal clauses include: the verb with its complex inflec¬tional system; the position before and after the verb; and prepositions. The pragmatically neutral clause begins with the verb, which may be followed by a noun phrase. The posi¬tion after the verb in non-sequential clauses is the coding means for the subject role of the noun phrase. The position before the verb is one of the coding means for topicalization and focus. The categories encoded in the verbal clauses are different for pronominal and nominal constituents. For pronominal constituents, the language distinguishes between the subject, direct object, and indirect object. For nominal constituents, the language distinguishes between the subject; the non-subject (which is not the same as object); and a variety of semantic relations that include the benefactive but not the indirect object. Given the richness of semantic information coded on the verb, the description of verbal clauses has to begin with the description of the morphology of the verb.

<h3 id="The morphology of the verb">The morphology of the verb</h3>

Verbs, unlike nouns, cannot begin with a vowel. It is necessary to postulate for verbs the category ‘root’, consisting of one or more underlying consonants, a tone (or tones, for polysyllabic verbs), and the first vowel. Other vowels code specific syntactic or semantic functions of the subject, the point of view from which the event is presented, the type of clause, and the aspect. Many polysyllabic verbs with the vowel _i_ code movement away from or separation from a source or a previously mentioned location of either the subject or the object: _ɗífà_ ‘hide’, _tsíhlà_ ‘husk’, _xídà_ ‘bite’, _gìgɗá_ ‘sift’, _fìɗá_ ‘plane \[wood\]’. A verb may be simple or reduplicated. Different reduplicated forms code perfective and progressive aspects, and verbal plurality. Subject pronouns are suffixed to the simple and reduplicated forms. Object pronouns are infixed in the reduplicated forms. Both simple and reduplicated verb may have a variety of verbal extensions suffixed to the simple verb and infixed in the reduplicated verb. 

<h3 id="Verbal nouns">Verbal nouns</h3>

There are two types of verbal nouns. One type ends in the vowel _u_ or _i_. The conditions determining whether the high vowel is front rather than back are not phonological, because some verbs can have both types of nouns, one with a front vowel and the other with a back vowel. For most verbal nouns, substituting the front vowel for the back, or the back vowel for the front, results in nonsense words. The tonal pattern of the verbal noun is the same as that of the verb.

  

<table class="table table-bordered">
<caption>Table 10: Verbal nouns ending in 'u'</caption>
<thead>
<tr>
<th>Verb</th>
<th></th>
<th>Verbal noun</th>
<th></th>
</tr>
</thead>
<tbody>
<tr>
<td><em>kátá</em></td>
<td>'to help</td>
<td><em>kátú</em></td>
<td>'help'</td>
</tr>
<tr>
<td><em>và</em></td>
<td>'to light a fire'</td>
<td><em>vú</em></td>
<td>'fire'</td>
</tr>
<tr>
<td><em>skálá</em></td>
<td>'to dance'</td>
<td><em>skálú</em></td>
<td>'dance'</td>
</tr>
<tr>
<td><em>ghálá</em></td>
<td>'to steal'</td>
<td><em>ghálú</em></td>
<td>'thief/theft'</td>
</tr>
</tbody>
</table>

  

Polyconsonantal verbs that have the initial vowel _i_ have the nominal form ending in _i_:

  

<table class="table table-bordered">
<caption>Table 11: Verbal nouns ending in 'i'</caption>
<thead>
<tr>
<th><em>vníxá</em></th>
<th>'to vomit'</th>
<th><em>vníxí</em></th>
<th>'vomit'</th>
</tr>
</thead>
<tbody>
<tr>
<td><em>xí'ídá</em></td>
<td>'to bite'</td>
<td><em>xí'ídí</em></td>
<td>'bite'</td>
</tr>
<tr>
<td><em>fìdá</em></td>
<td>'to plane (wood)'</td>
<td><em>fìfí</em></td>
<td>'planing'</td>
</tr>
</tbody>
</table>
<h3 id="Verbal plurality">Verbal plurality</h3>

Verbs in Hdi display the distinction of number. The unmarked form does not code number; the marked form codes verbal plurality, which implies plurality of the event, plurality of the subject of an intransitive verb, or plurality of the object of a transitive verb. There are three means to code the plurality of the verb: the suffix _á_, reduplication, and lexical suppletion. The plural marker _á_ is used only with polyconsonantal verbs. The marker _á_ is inserted after the first consonant of the verb. Thus the plural form of the verb _xná_ ‘slaughter’ is _x-á-ná_:

<table><tbody>
<tr><td><strong>
    (68)
</strong></td><td class="object-language" colspan="3"><em>kà x-á-ná-tá gù-xà</em></td></tr>
<tr><td></td><td class="morpheme">kà</td><td class="morpheme">x-á-ná-tá</td><td class="morpheme">gù-xà</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">slaugher-<span style="font-variant: small-caps;">PL-DEM-REF</span></td><td class="gloss">goat-<span style="font-variant: small-caps;">PL</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'he slaughtered goats'</td></tr>
</tbody></table>

Formation of the plural through reduplication for monosyllabic verbs involves leftward reduplication of the consonant and the insertion of the vowel _á_ after the reduplicated consonant. The product of such reduplication can be reduplicated further to code the perfective aspect:

<table><tbody>
<tr><td><strong>
    (69)
</strong></td><td class="object-language" colspan="1"><em>d-á-ɗà-gá-d-á-ɗà</em></td></tr>
<tr><td></td><td class="morpheme">d-á-ɗà-gá-d-á-ɗà</td></tr>
<tr><td></td><td class="gloss">fall-<span style="font-variant: small-caps;">PL-INN</span>-fall</td></tr>
<tr><td></td><td class="translation" colspan="1">'they fell down'</td></tr>
</tbody></table>

Compare the verb unmarked for number:

<table><tbody>
<tr><td><strong>
    (70)
</strong></td><td class="object-language" colspan="1"><em>dɗà-gá-dɗà</em></td></tr>
<tr><td></td><td class="morpheme">dɗà-gá-dɗà</td></tr>
<tr><td></td><td class="gloss">fall-<span style="font-variant: small-caps;">INN</span>-fall</td></tr>
<tr><td></td><td class="translation" colspan="1">'he fell down'</td></tr>
</tbody></table>

When the verb is transitive, the plural marker codes plurality of the object or plurality of the action. The object does not have to be marked for plural:

<table><tbody>
<tr><td><strong>
    (71)
</strong></td><td class="object-language" colspan="1"><em>bá-bà-f-bá-bà</em></td></tr>
<tr><td></td><td class="morpheme">bá-bà-f-bá-bà</td></tr>
<tr><td></td><td class="gloss">build-build-build-build</td></tr>
<tr><td></td><td class="translation" colspan="1">'he built many things' (not 'rebuilt the same things many times')</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (72)
</strong></td><td class="object-language" colspan="5"><em>snà-n-sn-íyù tá x-á-n-áy-tán tá hlà</em></td></tr>
<tr><td></td><td class="morpheme">snà-n-sn-íyù</td><td class="morpheme">tá</td><td class="morpheme">x-á-n-áy-tán</td><td class="morpheme">tá</td><td class="morpheme">hlà</td></tr>
<tr><td></td><td class="gloss">hear-3-hear-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">cut-<span style="font-variant: small-caps;">PL-PO-3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">cow</td></tr>
<tr><td></td><td class="translation" colspan="5">'I heard them slaughter cows' (note that the object is not marked for plurality)</td></tr>
</tbody></table>

Cf.:

<table><tbody>
<tr><td><strong>
    (73)
</strong></td><td class="object-language" colspan="5"><em>snà-n-sn-íyù tá xn-áy-tán tá hlà</em></td></tr>
<tr><td></td><td class="morpheme">snà-n-sn-íyù</td><td class="morpheme">tá</td><td class="morpheme">xn-áy-tán</td><td class="morpheme">tá</td><td class="morpheme">hlà</td></tr>
<tr><td></td><td class="gloss">hear-3-hear-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">cut-<span style="font-variant: small-caps;">PO-3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">cow</td></tr>
<tr><td></td><td class="translation" colspan="5">'I heard them slaughter a cow'</td></tr>
</tbody></table>

For bisyllabic verbs, the plural is formed by leftward repetition of the first syllable. In the perfective aspect the reduplicated theme of the verb is repeated twice:

<table><tbody>
<tr><td><strong>
    (74)
</strong></td><td class="object-language" colspan="4"><em>ɗá-ɗáxá-ná-f-ɗá-ɗáxá tá lgùt-á zwán-ì</em></td></tr>
<tr><td></td><td class="morpheme">ɗá-ɗáxá-ná-f-ɗá-ɗáxá</td><td class="morpheme">tá</td><td class="morpheme">lgùt-á</td><td class="morpheme">zwán-ì</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">PL</span>-sew-<span style="font-variant: small-caps;">DEM-UP-PL</span>-sew</td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">dress-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">child-<span style="font-variant: small-caps;">PL</span></td></tr>
<tr><td></td><td class="translation" colspan="4">'he sewed the children's clothing'</td></tr>
</tbody></table>
<h3 id="Coding relationships between the predicate and noun phrases">Coding relationships between the predicate and noun phrases</h3>

The coding means for the relationship between the predicate and noun phrases include: the position directly after the verb; inherent properties of the verb; preposition _tá_; other prepositions; and verbal extensions. Several of these means may co-occur within the same clause.

The noun phrase (but not the prepositional phrase) directly following the verb in clauses other than sequential clauses is interpreted as subject:

<table><tbody>
<tr><td><strong>
    (75)
</strong></td><td class="object-language" colspan="3"><em>dzà’á skwá-p-skwá nàsàrá-ngrá</em></td></tr>
<tr><td></td><td class="morpheme">dzà’á</td><td class="morpheme">skwá-p-skwá</td><td class="morpheme">nàsàrá-ngrá</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">FUT</span>-sew-<span style="font-variant: small-caps;">DEM-UP-PL</span>-sew</td><td class="gloss">buy-<span style="font-variant: small-caps;">OUT</span>-buy</td><td class="gloss">boss-black</td></tr>
<tr><td></td><td class="translation" colspan="3">'the black boss is going to sell . . .'</td></tr>
</tbody></table>

In sequential clauses, there is no formal distinction between the nominal subject and the nominal object. In sentences containing sequential clauses, one usually expects the first clause to mention the subject, while subsequent clauses will not overtly mention the subject.. In the following example, the first clause has the subject following the verb. In the sequential clauses within the same sentence, the noun phrase that follows the verb is interpreted as object:

<table><tbody>
<tr><td><strong>
    (76)
</strong></td><td class="object-language" colspan="8"><em>kà hlí’yá-f-tá zvàxw kà ɗáwá-f-tá ntfàn ɗáwá-f-xà-tá dàwrà</em></td></tr>
<tr><td></td><td class="morpheme">kà</td><td class="morpheme">hlí’yá-f-tá</td><td class="morpheme">zvàxw</td><td class="morpheme">kà</td><td class="morpheme">ɗáwá-f-tá</td><td class="morpheme">ntfàn</td><td class="morpheme">ɗáwá-f-xà-tá</td><td class="morpheme">dàwrà</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span>-sew-<span style="font-variant: small-caps;">DEM-UP-PL</span>-sew</td><td class="gloss">leave-<span style="font-variant: small-caps;">UP-REF</span></td><td class="gloss">bat</td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span>-sew-<span style="font-variant: small-caps;">DEM-UP-PL</span>-sew</td><td class="gloss">ask-<span style="font-variant: small-caps;">UP-REF</span></td><td class="gloss">glue</td><td class="gloss">ask-<span style="font-variant: small-caps;">UP-ALSO-REF</span></td><td class="gloss">cloth</td></tr>
<tr><td></td><td class="translation" colspan="8">'the bat left and asked for glue and also for clothing'</td></tr>
</tbody></table>
<h3 id="Preposition &lt;em&gt;tá&lt;/em&gt;">Preposition <em>tá</em></h3>

This section presents analyses different from the ones in Frajzyngier with Shay 2002 and includes some argumentation to support the new analyses. The form _tá_, qua preposition, indicates that the noun phrase that follows it is not the subject. As demonstrated throughout examples in the dictionary, this noun is very frequently the object of the clause:

<table><tbody>
<tr><td><strong>
    (77)
</strong></td><td class="object-language" colspan="3"><em>tsghà-k-tsghà 	tá ceedì </em></td></tr>
<tr><td></td><td class="morpheme">tsghà-k-tsghà </td><td class="morpheme">tá</td><td class="morpheme">ceedì</td></tr>
<tr><td></td><td class="gloss">send-<span style="font-variant: small-caps;">INN</span>-send</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">money</td></tr>
<tr><td></td><td class="translation" colspan="3">'he sent money in'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (78)
</strong></td><td class="object-language" colspan="5"><em>xúxúrà-f-xúxúrà tá ghrùm tá sú </em></td></tr>
<tr><td></td><td class="morpheme">xúxúrà-f-xúxúrà</td><td class="morpheme">tá</td><td class="morpheme">ghrùm</td><td class="morpheme">tá</td><td class="morpheme">sú</td></tr>
<tr><td></td><td class="gloss">drill-<span style="font-variant: small-caps;">UP</span>-drill</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">hole</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">tree</td></tr>
<tr><td></td><td class="translation" colspan="5">'he made a hole in a tree'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (79)
</strong></td><td class="object-language" colspan="4"><em>zà-ná-ghú-zá ɗwàk tá dzúmá </em></td></tr>
<tr><td></td><td class="morpheme">zà-ná-ghú-zá</td><td class="morpheme">ɗwàk</td><td class="morpheme">tá</td><td class="morpheme">dzúmá</td></tr>
<tr><td></td><td class="gloss">eat-<span style="font-variant: small-caps;">DEM-SO</span>-eat</td><td class="gloss">termite</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">hay</td></tr>
<tr><td></td><td class="translation" colspan="4">'the termites have eaten part of the hay'</td></tr>
</tbody></table>

Not every complement of the preposition _tá_, however, is the direct object. Consider the verb _hlíná_ ‘warm up’. The verb is intransitive, as the entity that gets warmed up is always the subject. This verb cannot be used transitively, and yet this verb can have a complement marked by the preposition _tá_. The preposition indicates the source of heat:

<table><tbody>
<tr><td><strong>
    (80)
</strong></td><td class="object-language" colspan="3"><em>hlíná-f-hlíná tá fìtík </em></td></tr>
<tr><td></td><td class="morpheme">hlíná-f-hlíná</td><td class="morpheme">tá</td><td class="morpheme">fìtík</td></tr>
<tr><td></td><td class="gloss">warm-<span style="font-variant: small-caps;">UP</span>-warm</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">fire</td></tr>
<tr><td></td><td class="translation" colspan="3">'he warmed up with the sun'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (81)
</strong></td><td class="object-language" colspan="3"><em>hlíná-f-hlíná tá vúvú  </em></td></tr>
<tr><td></td><td class="morpheme">hlíná-f-hlíná</td><td class="morpheme">tá</td><td class="morpheme">vúvú </td></tr>
<tr><td></td><td class="gloss">warm-<span style="font-variant: small-caps;">UP</span>-warm</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">fire</td></tr>
<tr><td></td><td class="translation" colspan="3">'he warmed up with the fire'</td></tr>
</tbody></table>

One cannot say ‘the Sun warmed him up’ where the Sun is the subject and the third-person argument is the object. Similarly with the verb _búkwá_ ‘cover’: When it occurs with the affectedness of the subject extension, the verb means that the subject is being covered:

<table><tbody>
<tr><td><strong>
    (82)
</strong></td><td class="object-language" colspan="3"><em>búkwá-vá-búkw-í tá lgùt</em></td></tr>
<tr><td></td><td class="morpheme">búkwá-vá-búkw-í</td><td class="morpheme">tá</td><td class="morpheme">lgùt</td></tr>
<tr><td></td><td class="gloss">cover-<span style="font-variant: small-caps;">AS</span>-cover-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">cloth</td></tr>
<tr><td></td><td class="translation" colspan="3">'I covered myself with a cloth'</td></tr>
</tbody></table>

The role of the noun phrase marked by the preposition _tá_ must be deduced from the inherent properties of the verb and/or from the extensions added to the verb. Thus, if the verb has the associative extension _ndá_, this extension forces the interpretation of the noun marked by _tá_ as an entity about which one thinks or remembers. With the verb _dúkwá_ ‘realize, become aware’ the associative extension marks the existence of the object of awareness:

<table><tbody>
<tr><td><strong>
    (83)
</strong></td><td class="object-language" colspan="4"><em>dúkwá-f-ndá-dúkwá mbítsá tá pìtsákw-á-ní </em></td></tr>
<tr><td></td><td class="morpheme">dúkwá-f-ndá-dúkwá</td><td class="morpheme">mbítsá</td><td class="morpheme">tá</td><td class="morpheme">pìtsákw-á-ní</td></tr>
<tr><td></td><td class="gloss">realize-<span style="font-variant: small-caps;">UP-ASSC</span>-realize</td><td class="gloss">Mbítsá</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">hoe-<span style="font-variant: small-caps;">GEN-3SG</span></td></tr>
<tr><td></td><td class="translation" colspan="4">'Mbitsa has found about his hoe'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (84)
</strong></td><td class="object-language" colspan="3"><em>dúkwá-f-ndá-dúkw-ì tá sá-ghá-nì</em></td></tr>
<tr><td></td><td class="morpheme">dúkwá-f-ndá-dúkw-ì</td><td class="morpheme">tá</td><td class="morpheme">sá-ghá-nì</td></tr>
<tr><td></td><td class="gloss">realize-<span style="font-variant: small-caps;">UP-ASSC</span>-realize-1SG</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">come-<span style="font-variant: small-caps;">D:GO-GEN-3SG</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'I became unexpectedly aware of his arrival'</td></tr>
</tbody></table>

When the particle _tá_ precedes a verb or a clause, it marks the verb or clause as a comment on the preceding constituent, which may be clausal or nominal. Here is an example where the form _tá_ marks the comment on the element in focus:

<table><tbody>
<tr><td><strong>
    (85)
</strong></td><td class="object-language" colspan="5"><em>tíngìl	vàzák tá lá-ghà tántán</em></td></tr>
<tr><td></td><td class="morpheme">tíngìl</td><td class="morpheme">vàzák</td><td class="morpheme">tá</td><td class="morpheme">lá-ghà</td><td class="morpheme">tántán</td></tr>
<tr><td></td><td class="gloss">first</td><td class="gloss">rooster</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">go-<span style="font-variant: small-caps;">D:PVG</span></td><td class="gloss">first</td></tr>
<tr><td></td><td class="translation" colspan="5">'It is Rooster that arrived first'</td></tr>
</tbody></table>

In the following sentence, three noun phrases following the verb are preceded by the marker _tá_. In the first phrase the marker precedes the object, in the second it precedes the attribute of the object, and in the third it precedes the relative clause, i.e. the comment on the head of the relative clause:

<table><tbody>
<tr><td><strong>
    (86)
</strong></td><td class="object-language" colspan="9"><em>ɓàràká-f-ɓàràkú-lú tá tsá xàlá tá mndú	tá mtútà yá</em></td></tr>
<tr><td></td><td class="morpheme">ɓàràká-f-ɓàràkú-lú</td><td class="morpheme">tá</td><td class="morpheme">tsá</td><td class="morpheme">xàlá</td><td class="morpheme">tá</td><td class="morpheme">mndú</td><td class="morpheme">tá</td><td class="morpheme">mtútà</td><td class="morpheme">yá</td></tr>
<tr><td></td><td class="gloss">celebrate-<span style="font-variant: small-caps;">UP</span>-celebrate-<span style="font-variant: small-caps;">HUM</span></td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss"><span style="font-variant: small-caps;">DEF</span></td><td class="gloss">advanced age</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">man</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">dead</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td></tr>
<tr><td></td><td class="translation" colspan="9">'One celebrated [through a trotting dance] the advanced age of the deceased (lit. 'of the person who died')'</td></tr>
</tbody></table>
<h3 id="Point of view of the subject and goal orientation">Point of view of the subject and goal orientation</h3>

Both the point of view of the subject/source and goal orientation, i.e. indication that the event has a goal, are marked by verbal extensions. 

The point of view of the subject/source is marked in the perfective aspect by the extension _u_, which assumes the tone of the verb:

<table><tbody>
<tr><td><strong>
    (87)
</strong></td><td class="object-language" colspan="1"><em>z-ú-zà</em></td></tr>
<tr><td></td><td class="morpheme">abwilyep</td></tr>
<tr><td></td><td class="gloss">eat-<span style="font-variant: small-caps;">SO</span>-eat</td></tr>
<tr><td></td><td class="translation" colspan="1">this man is a sorcerer</td></tr>
</tbody></table>

Some intransitive verbs must occur with the marker _u_:

<table><tbody>
<tr><td><strong>
    (88)
</strong></td><td class="object-language" colspan="3"><em>kà mt-ú-tá dá-nì</em></td></tr>
<tr><td></td><td class="morpheme">kà</td><td class="morpheme">mt-ú-tá</td><td class="morpheme">dá-nì</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">die-<span style="font-variant: small-caps;">SO-REF</span></td><td class="gloss">father-<span style="font-variant: small-caps;">3SG</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'and his father died'</td></tr>
</tbody></table>

In the imperfective aspect, the point of view of the subject is marked by the suffix _kú_, glossed as ABS (for ‘absolutive’) in Frajzyngier with Shay 2002:

<table><tbody>
<tr><td><strong>
    (89)
</strong></td><td class="object-language" colspan="6"><em>xàɗ-áŋni tà mtà-kú ndá	mtà wà</em></td></tr>
<tr><td></td><td class="morpheme">xàɗ-áŋni</td><td class="morpheme">tà</td><td class="morpheme">mtà-kú</td><td class="morpheme">ndá</td><td class="morpheme">mtà</td><td class="morpheme">wà</td></tr>
<tr><td></td><td class="gloss">lack-<span style="font-variant: small-caps;">1PL:EXCL</span></td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">die-<span style="font-variant: small-caps;">ABS</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">death</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td></tr>
<tr><td></td><td class="translation" colspan="6">'we do not die [when we are old]'</td></tr>
</tbody></table>

When the noun that follows the verb is not preceded by a preposition, it is interpreted as the subject: 

<table><tbody>
<tr><td><strong>
    (90)
</strong></td><td class="object-language" colspan="2"><em>dr-ú-drá xàsúù</em></td></tr>
<tr><td></td><td class="morpheme">dr-ú-drá</td><td class="morpheme">xàsúù</td></tr>
<tr><td></td><td class="gloss">burn-<span style="font-variant: small-caps;">SO</span>-burn</td><td class="gloss">wood</td></tr>
<tr><td></td><td class="translation" colspan="2">'the wood burned'</td></tr>
</tbody></table>

Coding the point of view of the subject is not a means of intransitivizing the verb. A verb coding the point of view of the subject can co-occur with an object marked by the preposition _tá_:

<table><tbody>
<tr><td><strong>
    (91)
</strong></td><td class="object-language" colspan="3"><em>hlr-ú-hlrà tá pìtsákw</em></td></tr>
<tr><td></td><td class="morpheme">hlr-ú-hlrà</td><td class="morpheme">tà</td><td class="morpheme">pìtsákw</td></tr>
<tr><td></td><td class="gloss">forge-<span style="font-variant: small-caps;">SO</span>-forge</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">hoe</td></tr>
<tr><td></td><td class="translation" colspan="3">'he forged himself a hoe'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (92)
</strong></td><td class="object-language" colspan="3"><em>nd-ù-ndà tá ghwánì </em></td></tr>
<tr><td></td><td class="morpheme">nd-ù-ndà</td><td class="morpheme">tà</td><td class="morpheme">ghwánì</td></tr>
<tr><td></td><td class="gloss">swallow-<span style="font-variant: small-caps;">SO</span>-swallow</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">medicine</td></tr>
<tr><td></td><td class="translation" colspan="3">'he swallowed the medicine'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (93)
</strong></td><td class="object-language" colspan="4"><em>b-ù-bá tá xgà yà </em></td></tr>
<tr><td></td><td class="morpheme">b-ù-bá</td><td class="morpheme">tà</td><td class="morpheme">xgà</td><td class="morpheme">yà</td></tr>
<tr><td></td><td class="gloss">build-<span style="font-variant: small-caps;">SO</span>-build</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">house</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td></tr>
<tr><td></td><td class="translation" colspan="4">'he built himself a house'</td></tr>
</tbody></table>

The goal-orientation suffix _-a_ can be added either directly to the verbal root or to the point of view of subject marker _u_. In the sequence /C\[labial or velar\] u a/, the vowel _u_ is reduced to the feature \[round\], realized as labialization of the preceding consonant. The goal-oriented marker codes the event as directed toward a goal and thereby implies that the subject is controlling:

<table><tbody>
<tr><td><strong>
    (94)
</strong></td><td class="object-language" colspan="3"><em>fw-á-fwà tá ìmí</em></td></tr>
<tr><td></td><td class="morpheme">fw-á-fwà</td><td class="morpheme">tá</td><td class="morpheme">ìmí</td></tr>
<tr><td></td><td class="gloss">heat-<span style="font-variant: small-caps;">PVG</span>-heat</td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">water</td></tr>
<tr><td></td><td class="translation" colspan="3">'he heated water'</td></tr>
</tbody></table>

Cf.:

<table><tbody>
<tr><td><strong>
    (95)
</strong></td><td class="object-language" colspan="2"><em>fú-fwà ìmí</em></td></tr>
<tr><td></td><td class="morpheme">fú-fwà</td><td class="morpheme">ìmí</td></tr>
<tr><td></td><td class="gloss">heat up-heat up</td><td class="gloss">water</td></tr>
<tr><td></td><td class="translation" colspan="2">'water heated up'</td></tr>
</tbody></table>

Consider the verb _ɗvà_ ‘like’. If the vowel _u_ is added to the stem ending in _á_, the meaning of the verb involves control on the part of the subject, resulting in meanings corresponding to ‘choose’, ‘select’, ‘prefer’:

<table><tbody>
<tr><td><strong>
    (96)
</strong></td><td class="object-language" colspan="5"><em>kà ɗvá-úgh-tá mákwà tá zvàxw</em></td></tr>
<tr><td></td><td class="morpheme">kà</td><td class="morpheme">ɗvá-úgh-tá</td><td class="morpheme">mákwà</td><td class="morpheme">tá</td><td class="morpheme">zvàxw</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">like-<span style="font-variant: small-caps;">SO-REF</span></td><td class="gloss">girl</td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">bat</td></tr>
<tr><td></td><td class="translation" colspan="5">'the girl chose the bat [for herself]'</td></tr>
</tbody></table>

If the vowel _u_ is added directly to the verbal root, the verbal stem means ‘to love’, a process that does not involve control:

<table><tbody>
<tr><td><strong>
    (97)
</strong></td><td class="object-language" colspan="5"><em>kà ɗv-ú-tá mákwà tá zvàxw</em></td></tr>
<tr><td></td><td class="morpheme">kà</td><td class="morpheme">ɗv-ú-tá</td><td class="morpheme">mákwà</td><td class="morpheme">tá</td><td class="morpheme">zvàxw</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">like-<span style="font-variant: small-caps;">SO-REF</span></td><td class="gloss">girl</td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">bat</td></tr>
<tr><td></td><td class="translation" colspan="5">'the girl liked the bat'</td></tr>
</tbody></table>
<h3 id="Classes of verbs">Classes of verbs</h3>

There are four classes of verbs, based on the inclusion or exclusion of a second nominal argument (‘transitivity’): unspecified; inherently transitive; inherently intransitive; and labile, i.e. both transitive and intransitive. 

<h4 id="Unspecified class">Unspecified class</h4>

An unspecified verb is a verb that does not inherently imply the presence or absence of an object. As a result, the presence of the third-person object must be overtly marked, and the absence of the object must also be overtly marked. With these verbs, the affectedness of the subject must also be overtly marked. The affectedness of the subject is marked by the point of view of subject extension -u or the affectedness of the subject extension _va_. Consider the verb _ɗífà_ ‘hide’. To indicate that the subject is the participant that hides himself, the point of view of subject marker _u_ must be used:

<table><tbody>
<tr><td><strong>
    (98)
</strong></td><td class="object-language" colspan="2"><em>ɗífà-u-ɗífà vàzák</em></td></tr>
<tr><td></td><td class="morpheme">ɗífà-u-ɗífà</td><td class="morpheme">vàzák</td></tr>
<tr><td></td><td class="gloss">hide-<span style="font-variant: small-caps;">SO</span>-hide</td><td class="gloss">rooster</td></tr>
<tr><td></td><td class="translation" colspan="2">'the rooster hid himself'</td></tr>
</tbody></table>

To indicate that the event has two participants, one controlling and the other undergoing the event, the verb must have the additional-argument marker _ná_ (glossed as DEM). The evidence that the marker _ná_ is not a third-person singular object pronoun is provided by the fact that it can co-occur with the verb in the plural form, implying the presence of multiple objects:

<table><tbody>
<tr><td><strong>
    (99)
</strong></td><td class="object-language" colspan="1"><em>ɗíf-ɗífà-ná-tà </em></td></tr>
<tr><td></td><td class="morpheme">ɗíf-ɗífà-ná-tà</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">PL</span>-hide-<span style="font-variant: small-caps;">DEM-REF</span></td></tr>
<tr><td></td><td class="translation" colspan="1">'hide many things'</td></tr>
</tbody></table>

The nominal argument that follows the verb is interpreted as the subject of the transitive predication: 

<table><tbody>
<tr><td><strong>
    (100)
</strong></td><td class="object-language" colspan="2"><em>ɗífà-ná-tà vàzák </em></td></tr>
<tr><td></td><td class="morpheme">ɗífà-ná-tà</td><td class="morpheme">vàzák</td></tr>
<tr><td></td><td class="gloss">hide-<span style="font-variant: small-caps;">DEM-REF</span></td><td class="gloss">rooster</td></tr>
<tr><td></td><td class="translation" colspan="2">'it is the Rooster that hid him'</td></tr>
</tbody></table>

Consider now the verb _ghúyá_ ‘get drunk’. To indicate that the subject got drunk, the verb must have the point of view of the subject extension _u_:

<table><tbody>
<tr><td><strong>
    (101)
</strong></td><td class="object-language" colspan="1"><em>ghúy-ú-ghúyá</em></td></tr>
<tr><td></td><td class="morpheme">ghúy-ú-ghúyá </td></tr>
<tr><td></td><td class="gloss">drink-<span style="font-variant: small-caps;">SO</span>-drink</td></tr>
<tr><td></td><td class="translation" colspan="1">'he got drunk'</td></tr>
</tbody></table>

To indicate that there is a participant who drank as a result of the action of somebody else, the marker _ná_ must be suffixed to the verb:

<table><tbody>
<tr><td><strong>
    (102)
</strong></td><td class="object-language" colspan="1"><em>ghúy-ná-f-ghúy-ì </em></td></tr>
<tr><td></td><td class="morpheme">ghúy-ná-f-ghúy-ì </td></tr>
<tr><td></td><td class="gloss">drink-<span style="font-variant: small-caps;">DEM-UP</span>-drink-<span style="font-variant: small-caps;">1SG</span></td></tr>
<tr><td></td><td class="translation" colspan="1">'I made him drink'</td></tr>
</tbody></table>

Here is an example of the use of the extension _iŋ_, which allows the deployment of the second argument. The verb is _gúná_ ‘open’:

<table><tbody>
<tr><td><strong>
    (103)
</strong></td><td class="object-language" colspan="3"><em>gún-iŋ-gúná tá sígà</em></td></tr>
<tr><td></td><td class="morpheme">gún-iŋ-gúná</td><td class="morpheme">tá</td><td class="morpheme">sígà</td></tr>
<tr><td></td><td class="gloss">open-<span style="font-variant: small-caps;">AWAY</span>-open</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">pot</td></tr>
<tr><td></td><td class="translation" colspan="3">'he opened the pot'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (104)
</strong></td><td class="object-language" colspan="2"><em>gún-ú-gúná sígà</em></td></tr>
<tr><td></td><td class="morpheme">gún-ú-gúná</td><td class="morpheme">sígà</td></tr>
<tr><td></td><td class="gloss">open-<span style="font-variant: small-caps;">SO</span>-open</td><td class="gloss">pot</td></tr>
<tr><td></td><td class="translation" colspan="2">'the pot opened'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (105)
</strong></td><td class="object-language" colspan="5"><em>tsá sígà tá gún-ú-tà yá</em></td></tr>
<tr><td></td><td class="morpheme">tsá</td><td class="morpheme">sígà</td><td class="morpheme">tá</td><td class="morpheme">gún-ú-tà</td><td class="morpheme">yá</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">DEF</span></td><td class="gloss">pot</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">open-<span style="font-variant: small-caps;">SO-REF</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td></tr>
<tr><td></td><td class="translation" colspan="5">'the pot that opened'</td></tr>
</tbody></table>

And here is an example with the verb _làɓ_ ‘mix’:

<table><tbody>
<tr><td><strong>
    (106)
</strong></td><td class="object-language" colspan="4"><em>làɓ-ú-làɓá ɓìdá ndá vàrà</em></td></tr>
<tr><td></td><td class="morpheme">làɓ-ú-làɓá</td><td class="morpheme">ɓìdá</td><td class="morpheme">ndá</td><td class="morpheme">vàrà</td></tr>
<tr><td></td><td class="gloss">mix-<span style="font-variant: small-caps;">SO</span>-mix</td><td class="gloss">millet</td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">beans</td></tr>
<tr><td></td><td class="translation" colspan="4">'millet and beans got mixed up'</td></tr>
</tbody></table>

Compare with the additional-argument marker _ná_:

<table><tbody>
<tr><td><strong>
    (107)
</strong></td><td class="object-language" colspan="6"><em>làɓà-ná-f-làɓá zwáŋà-ɗà tá ɓìdá ndá vàrà</em></td></tr>
<tr><td></td><td class="morpheme">làɓà-ná-f-làɓá</td><td class="morpheme">zwáŋà-ɗà</td><td class="morpheme">tá</td><td class="morpheme">ɓìdá</td><td class="morpheme">ndá</td><td class="morpheme">vàrà</td></tr>
<tr><td></td><td class="gloss">mix-<span style="font-variant: small-caps;">DEM</span>-mix</td><td class="gloss">child:<span style="font-variant: small-caps;">GEN-1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">millet</td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">bean</td></tr>
<tr><td></td><td class="translation" colspan="6">'my child mixed up millet with beans'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (108)
</strong></td><td class="object-language" colspan="5"><em>ngá làɓà-ná-f-tà ndá ghúvà gù </em></td></tr>
<tr><td></td><td class="morpheme">ngá</td><td class="morpheme">làɓà-ná-f-tà</td><td class="morpheme">ndá</td><td class="morpheme">ghúvà</td><td class="morpheme">gù</td></tr>
<tr><td></td><td class="gloss"><span style="font-variant: small-caps;">NORM</span></td><td class="gloss">mix-<span style="font-variant: small-caps;">DEM-UP</span>-mix<span style="font-variant: small-caps;">REF</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">excrement</td><td class="gloss">goat</td></tr>
<tr><td></td><td class="translation" colspan="5">'one should mix it with goat excrement'</td></tr>
</tbody></table>

Consider now the verb _dvà_ ‘threaten’. Without any morphological marking, the verb does not imply the presence of the second argument:

<table><tbody>
<tr><td><strong>
    (109)
</strong></td><td class="object-language" colspan="1"><em>dvà-dvà </em></td></tr>
<tr><td></td><td class="morpheme">dvà-dvà</td></tr>
<tr><td></td><td class="gloss">threaten-threaten</td></tr>
<tr><td></td><td class="translation" colspan="1">'he reprimanded, threatened' (no specific object or addressee is implied or can be inferred)</td></tr>
</tbody></table>

The addition of the second nominal argument requires the insertion of the additional argument marker _ná_:

<table><tbody>
<tr><td><strong>
    (110)
</strong></td><td class="object-language" colspan="4"><em>dvà-ná-ghá-dvá mbítsá tá zwànì</em></td></tr>
<tr><td></td><td class="morpheme">dvà-ná-ghá-dvá</td><td class="morpheme">mbítsá</td><td class="morpheme">tá</td><td class="morpheme">zwànì</td></tr>
<tr><td></td><td class="gloss">threaten-<span style="font-variant: small-caps;">DEM-D:GO</span>-threaten</td><td class="gloss">Mbítsá</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">children</td></tr>
<tr><td></td><td class="translation" colspan="4">'Mbitsa threatened children' (ná cannot be omitted)</td></tr>
</tbody></table>
<h4 id="Inherently transitive verbs">Inherently transitive verbs</h4>

An inherently transitive verb takes a second argument, marked by the comment marker _tá_, without any changes to the verb. The third-person object is not overtly marked on the verb. Consider the verb _drà_ ‘burn’:

<table><tbody>
<tr><td><strong>
    (111)
</strong></td><td class="object-language" colspan="3"><em>drá-drà tá xàsú’ú</em></td></tr>
<tr><td></td><td class="morpheme">drá-drà</td><td class="morpheme">tá</td><td class="morpheme">xàsú’ú</td></tr>
<tr><td></td><td class="gloss">burn-burn</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">wood</td></tr>
<tr><td></td><td class="translation" colspan="3">'he burned wood [in order to get charcoal]'</td></tr>
</tbody></table>

To code the point of view of the subject, and to indicate that the single noun phrase has undergone the event, the verb has the subject-oriented extension _u_ and the noun phrase follows the verb without a preposition:

<table><tbody>
<tr><td><strong>
    (112)
</strong></td><td class="object-language" colspan="2"><em>dr-ú-drá xàsú’ù</em></td></tr>
<tr><td></td><td class="morpheme">dr-ú-drá</td><td class="morpheme">xàsú’ú</td></tr>
<tr><td></td><td class="gloss">burn-<span style="font-variant: small-caps;">SO</span>-burn</td><td class="gloss">wood</td></tr>
<tr><td></td><td class="translation" colspan="2">'the wood burned'</td></tr>
</tbody></table>

The fact that the subject is undergoing the action can also be marked by the affectedness of the subject extension. The verb _gìgìɗà_ ‘shake a tree’ is inherently transitive, as evidenced by its use with the object marked by the preposition _tá_ (with tentative extension _n_):

<table><tbody>
<tr><td><strong>
    (113)
</strong></td><td class="object-language" colspan="3"><em>gìgìɗà-n-gìgìɗá tá fú </em></td></tr>
<tr><td></td><td class="morpheme">gìgìɗà-n-gìgìɗá</td><td class="morpheme">tá</td><td class="morpheme">fú</td></tr>
<tr><td></td><td class="gloss">shake-<span style="font-variant: small-caps;">TENT</span>-shake</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">tree</td></tr>
<tr><td></td><td class="translation" colspan="3">'he shook the tree'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (114)
</strong></td><td class="object-language" colspan="2"><em>gìgìɗà-vá-gìgìɗá fú </em></td></tr>
<tr><td></td><td class="morpheme">gìgìɗà-vá-gìgìɗá</td><td class="morpheme">fú</td></tr>
<tr><td></td><td class="gloss">shake-<span style="font-variant: small-caps;">AS</span>-shake</td><td class="gloss">tree</td></tr>
<tr><td></td><td class="translation" colspan="2">'the tree shook'</td></tr>
</tbody></table>

or:

<table><tbody>
<tr><td><strong>
    (115)
</strong></td><td class="object-language" colspan="2"><em>gìgìɗ-ú-gìgìɗá fú </em></td></tr>
<tr><td></td><td class="morpheme">gìgìɗ-ú-gìgìɗá</td><td class="morpheme">fú</td></tr>
<tr><td></td><td class="gloss">shake-<span style="font-variant: small-caps;">SO</span>-shake</td><td class="gloss">tree</td></tr>
<tr><td></td><td class="translation" colspan="2">'the tree shook'</td></tr>
</tbody></table>

The additional-argument marker _ná_ with an inherently transitive verb usually codes the presence of an indirect object in the proposition:

<table><tbody>
<tr><td><strong>
    (116)
</strong></td><td class="object-language" colspan="2"><em>drá-ná-drà (ngá-ní)</em></td></tr>
<tr><td></td><td class="morpheme">drá-ná-drà</td><td class="morpheme">(ngá-ní)</td></tr>
<tr><td></td><td class="gloss">burn-<span style="font-variant: small-caps;">DEM</span>-burn</td><td class="gloss"><span style="font-variant: small-caps;">FOR-3SG</span></td></tr>
<tr><td></td><td class="translation" colspan="2">'he burned it (for him)'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (117)
</strong></td><td class="object-language" colspan="3"><em>dr-íŋ-drá tá xàsú’ú</em></td></tr>
<tr><td></td><td class="morpheme">dr-íŋ-drá</td><td class="morpheme">tá</td><td class="morpheme">xàsú’ú</td></tr>
<tr><td></td><td class="gloss">burn-<span style="font-variant: small-caps;">AWAY</span>-burn</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">wood</td></tr>
<tr><td></td><td class="translation" colspan="3">'he burned wood'</td></tr>
</tbody></table>

To code coreferentiality of the subject and object, the verb must have the affectedness of the subject extension v and the object must be marked by the preposition _tá_, whose complement is the noun _vghá_ ‘body’ followed by a possessive pronoun:

<table><tbody>
<tr><td><strong>
    (118)
</strong></td><td class="object-language" colspan="3"><em>dr-ú-v-drà tá vghá-ní</em></td></tr>
<tr><td></td><td class="morpheme">dr-ú-v-drà</td><td class="morpheme">tá</td><td class="morpheme">vghá-ní</td></tr>
<tr><td></td><td class="gloss">burn-<span style="font-variant: small-caps;">SO-AS</span>-burn</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">vghá-<span style="font-variant: small-caps;">3SG</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'he burned himself'</td></tr>
</tbody></table>

Here is an example with the verb _bà_ ‘build’. The nominal object is marked by the comment marker _tá_:

<table><tbody>
<tr><td><strong>
    (119)
</strong></td><td class="object-language" colspan="3"><em>b-í-dí-ɗí-f-bà tá xgá </em></td></tr>
<tr><td></td><td class="morpheme">b-í-dí-ɗí-f-bà</td><td class="morpheme">tá</td><td class="morpheme">xgá</td></tr>
<tr><td></td><td class="gloss">build-<span style="font-variant: small-caps;">1SG-UP</span>-build</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">house</td></tr>
<tr><td></td><td class="translation" colspan="3">'he built me a house'</td></tr>
</tbody></table>

The addition of the marker _ná_ with an inherently transitive verb indicates the presence of an indirect object:

<table><tbody>
<tr><td><strong>
    (120)
</strong></td><td class="object-language" colspan="1"><em>bà-ná-f-bà</em></td></tr>
<tr><td></td><td class="morpheme">bà-ná-f-bà </td></tr>
<tr><td></td><td class="gloss">build-<span style="font-variant: small-caps;">DEM-UP</span>-build</td></tr>
<tr><td></td><td class="translation" colspan="1">'build for someone'</td></tr>
</tbody></table>
<h4 id="Inherently intransitive verbs">Inherently intransitive verbs</h4>

An intransitive verb is a verb that requires the additional-argument marker _ná_ to indicate that there are two arguments in the proposition. Without such a marker, the noun phrase that follows the verb is interpreted as the subject. This is the case with the verb _hànà_ ‘lie down’, ‘sleep’, ‘pass the night’:

<table><tbody>
<tr><td><strong>
    (121)
</strong></td><td class="object-language" colspan="1"><em>hànà-hànà</em></td></tr>
<tr><td></td><td class="morpheme">hànà-hànà</td></tr>
<tr><td></td><td class="gloss">sleep-sleep</td></tr>
<tr><td></td><td class="translation" colspan="1">'he lay down/slept'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (122)
</strong></td><td class="object-language" colspan="1"><em>hànà-ná-hànà</em></td></tr>
<tr><td></td><td class="morpheme">hànà-ná-hànà</td></tr>
<tr><td></td><td class="gloss">sleep-<span style="font-variant: small-caps;">DEM</span>-sleep</td></tr>
<tr><td></td><td class="translation" colspan="1">'he made somebody lie down'</td></tr>
</tbody></table>

The presence of the additional-argument marker in the verb does not necessarily indicate the presence of either a direct or indirect object. It may indicate a presence of what in some Indo-European languages would correspond to adjunct: 

<table><tbody>
<tr><td><strong>
    (123)
</strong></td><td class="object-language" colspan="1"><em>hànà-ná-ghá-hànà</em></td></tr>
<tr><td></td><td class="morpheme">hànà-ná-ghá-hànà </td></tr>
<tr><td></td><td class="gloss">sleep-<span style="font-variant: small-caps;">DEM-D:GO</span>-sleep</td></tr>
<tr><td></td><td class="translation" colspan="1">'to lie on top of something'</td></tr>
</tbody></table>

An inherently intransitive verb does not require any markers when it occurs with only one argument. Consider the verb _gə̀má_ ‘meet’:

<table><tbody>
<tr><td><strong>
    (124)
</strong></td><td class="object-language" colspan="1"><em>gə̀má-f-gə̀má-xə̀n</em></td></tr>
<tr><td></td><td class="morpheme">gə̀má-f-gə̀má-xə̀n</td></tr>
<tr><td></td><td class="gloss">meet-<span style="font-variant: small-caps;">UP</span>-meet-<span style="font-variant: small-caps;">3PL</span></td></tr>
<tr><td></td><td class="translation" colspan="1">'they met'</td></tr>
</tbody></table>

One can add an object to inherently intransitive verbs if the verb has the additional-argument marker _ná_:

<table><tbody>
<tr><td><strong>
    (125)
</strong></td><td class="object-language" colspan="3"><em>gə̀mà-ná-f-gə̀m-í tá xə̀n</em></td></tr>
<tr><td></td><td class="morpheme">gə̀mà-ná-f-gə̀m</td><td class="morpheme">tá</td><td class="morpheme">xə̀n</td></tr>
<tr><td></td><td class="gloss">meet-<span style="font-variant: small-caps;">DEM-UP</span>-meet-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss"><span style="font-variant: small-caps;">3PL</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'I got them together'</td></tr>
</tbody></table>
<h4 id="Cognate object">Cognate object</h4>

A number of verbs are followed by cognate objects, i.e. objects linked semantically and phonologically with a specific verb. Such objects are marked by the comment marker _tá_. Cognate objects are often derived from the same root as the verb:

<table><tbody>
<tr><td><strong>
    (126)
</strong></td><td class="object-language" colspan="4"><em>ɗg-áy-tán tá ɗgú yá</em></td></tr>
<tr><td></td><td class="morpheme">ɗg-áy-tán</td><td class="morpheme">tá</td><td class="morpheme">ɗgú̀</td><td class="morpheme">yá̀</td></tr>
<tr><td></td><td class="gloss">thresh-<span style="font-variant: small-caps;">PO-3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">threshing(N)</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td></tr>
<tr><td></td><td class="translation" colspan="4">'While they were threshing'</td></tr>
</tbody></table>

Some intransitive verbs may be followed by an object marked by the preposition _tá_. These are, however, cognate objects. The cognate object may be followed by another object also marked by the comment marker _tá_:

<table><tbody>
<tr><td><strong>
    (127)
</strong></td><td class="object-language" colspan="5"><em>mbàzá-ná-mbàz-í tá mbàzá tá mbítsá </em></td></tr>
<tr><td></td><td class="morpheme">mbàzá-ná-mbàz-í</td><td class="morpheme">tá</td><td class="morpheme">mbàzá̀</td><td class="morpheme">tá</td><td class="morpheme">mbítsá</td></tr>
<tr><td></td><td class="gloss">wash-<span style="font-variant: small-caps;">DEM</span>-wash-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">washing(N)</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">Mbitsa</td></tr>
<tr><td></td><td class="translation" colspan="5">'I washed Mbitsa'</td></tr>
</tbody></table>

An example of such a verb is _tsúhà_ ‘cough’:

<table><tbody>
<tr><td><strong>
    (128)
</strong></td><td class="object-language" colspan="1"><em>tsúhà-tsúhà</em></td></tr>
<tr><td></td><td class="morpheme">tsúhà-tsúhà</td></tr>
<tr><td></td><td class="gloss">cough-cough</td></tr>
<tr><td></td><td class="translation" colspan="1">'he coughed'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (129)
</strong></td><td class="object-language" colspan="3"><em>tsúh-ín-tsúhà tá másáɓì/màgàsàr</em></td></tr>
<tr><td></td><td class="morpheme">tsúh-ín-tsúhà</td><td class="morpheme">tá</td><td class="morpheme">másáɓì/màgàsàr̀</td></tr>
<tr><td></td><td class="gloss">cough-<span style="font-variant: small-caps;">AWAY</span>-cough</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">flu/tuberculosis</td></tr>
<tr><td></td><td class="translation" colspan="3">'he coughed the flu/tuberculosis' (the only objects allowed with this verb)'</td></tr>
</tbody></table>

Hence, the presence of the cognate object does not make the verb transitive.

<h4 id="Labile verbs">Labile verbs</h4>

There is a class of verbs (‘labile’ verbs) that are both intransitive and transitive, as evidenced by the fact that the presence of the third-person object is not overtly marked on the verb and the affectedness of the subject is not marked by the source-oriented marker _u_. One such verb is _hà_ ‘close’. Here is an example of a clause with two arguments. The object is marked only by the preposition _tá_:

<table><tbody>
<tr><td><strong>
    (130)
</strong></td><td class="object-language" colspan="3"><em>hà-f-hà tá txà</em></td></tr>
<tr><td></td><td class="morpheme">hà-f-hà</td><td class="morpheme">tá</td><td class="morpheme">txà</td></tr>
<tr><td></td><td class="gloss">close-<span style="font-variant: small-caps;">UP</span>-close</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">door</td></tr>
<tr><td></td><td class="translation" colspan="3">'he closed the door'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (131)
</strong></td><td class="object-language" colspan="4"><em>hà-f-hà mbítsá tá txà</em></td></tr>
<tr><td></td><td class="morpheme">hà-f-hà</td><td class="morpheme">mbítsá</td><td class="morpheme">tá</td><td class="morpheme">txà</td></tr>
<tr><td></td><td class="gloss">close-<span style="font-variant: small-caps;">UP</span>-close</td><td class="gloss">Mbitsa</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">door</td></tr>
<tr><td></td><td class="translation" colspan="4">'Mbitsa closed the door'</td></tr>
</tbody></table>

Here is an example of the clause with one argument, the subject. The affectedness of the subject is not marked by the source-orientation marker _u_:

<table><tbody>
<tr><td><strong>
    (132)
</strong></td><td class="object-language" colspan="2"><em>hà-f-hà txà</em></td></tr>
<tr><td></td><td class="morpheme">hà-f-hà</td><td class="morpheme">txà</td></tr>
<tr><td></td><td class="gloss">close-<span style="font-variant: small-caps;">UP</span>-close</td><td class="gloss">door</td></tr>
<tr><td></td><td class="translation" colspan="2">'the door closed'</td></tr>
</tbody></table>
<h3 id="The function of the object pronouns">The function of the object pronouns</h3>

The following chart represents object pronouns:

  

<table class="table table-bordered">
<caption>Table 12: Object suffixes</caption>
<thead>
<tr>
<th>Person</th>
<th>Singular</th>
<th>Dual</th>
<th>Plural</th>
</tr>
</thead>
<tbody>
<tr>
<td>First</td>
<td>í; ɗ; í-xà</td>
<td>úú</td>
<td>mú (incl); ŋní (excl)</td>
</tr>
<tr>
<td>Second</td>
<td>ghá</td>
<td></td>
<td>ghúní</td>
</tr>
<tr>
<td>Third</td>
<td>Ø; ná</td>
<td></td>
<td>xə̀n</td>
</tr>
</tbody>
</table>

  

First- and second-person object pronouns can code the direct or indirect object, regardless of the verbs to which they are added. The form _ná_ with an inherently transitive verb codes the third-person singular indirect object:

<table><tbody>
<tr><td><strong>
    (133)
</strong></td><td class="object-language" colspan="3"><em>fáɗá-ná-fáɗá tá vwàx </em></td></tr>
<tr><td></td><td class="morpheme">fáɗá-ná-fáɗá</td><td class="morpheme">tá</td><td class="morpheme">vwàx</td></tr>
<tr><td></td><td class="gloss">clean-<span style="font-variant: small-caps;">DEM</span>-clean</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">field</td></tr>
<tr><td></td><td class="translation" colspan="3">'clean the field for him'</td></tr>
</tbody></table>

With other verbs, the form _ná_ suffixed to the verb indicates the presence of an additional participant, which may be a direct object. The form ná is used even if the direct object is plural, which is the evidence that ná is not the third-person singular object marker:

<table><tbody>
<tr><td><strong>
    (134)
</strong></td><td class="object-language" colspan="3"><em>dzrà-ná-f-dzrù-lù tá xǝ̀n </em></td></tr>
<tr><td></td><td class="morpheme">dzrà-ná-f-dzrù-lù</td><td class="morpheme">tá</td><td class="morpheme">xǝ̀n</td></tr>
<tr><td></td><td class="gloss">agree-<span style="font-variant: small-caps;">2SG-UP</span>-agree-<span style="font-variant: small-caps;">HUM</span></td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss"><span style="font-variant: small-caps;">3PL</span></td></tr>
<tr><td></td><td class="translation" colspan="3">'one has made them agree'</td></tr>
</tbody></table>

Compare the intransitive:

<table><tbody>
<tr><td><strong>
    (135)
</strong></td><td class="object-language" colspan="1"><em>dzrà-p-dzrá-xǝ̀n</em></td></tr>
<tr><td></td><td class="morpheme">dzrà-p-dzrá-xǝ̀n</td></tr>
<tr><td></td><td class="gloss">agree-<span style="font-variant: small-caps;">OUT</span>-agree-<span style="font-variant: small-caps;">3PL</span></td></tr>
<tr><td></td><td class="translation" colspan="1">'they agreed with each other'</td></tr>
</tbody></table>

The first-person singular object affixes are _i_, _i-xà_, and _ɗa_. The form _ɗa_ is a cognate of the first-person possessive marker ɗá. The pronoun i replaces the vowel of the preceding verb and assumes its grammatical tone, i.e. the tone that the verb has before the direct object:

<table><tbody>
<tr><td><strong>
    (136)
</strong></td><td class="object-language" colspan="1"><em>ks-ì-ksà</em></td></tr>
<tr><td></td><td class="morpheme">ks-ì-ksà</td></tr>
<tr><td></td><td class="gloss">touch-<span style="font-variant: small-caps;">1SG</span>-touch</td></tr>
<tr><td></td><td class="translation" colspan="1">'he touched me' or 'he wounded me' (<em>ksá</em> 'catch him/it!' has underlying high tone)</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (137)
</strong></td><td class="object-language" colspan="1"><em>kzl-ì-kzlà</em></td></tr>
<tr><td></td><td class="morpheme">kzl-ì-kzlà</td></tr>
<tr><td></td><td class="gloss">wait-<span style="font-variant: small-caps;">1SG</span>-wait</td></tr>
<tr><td></td><td class="translation" colspan="1">'he waited for me' (<em>kzlà</em> has underlying low tone)</td></tr>
</tbody></table>

The form _ixà_ is equivalent to the form _i_. The form _ixa_ occurs optionally when there are no other extensions to the verb:

<table><tbody>
<tr><td><strong>
    (138)
</strong></td><td class="object-language" colspan="1"><em>kzl-ìxà-kzlà</em></td></tr>
<tr><td></td><td class="morpheme">kzl-ìxà-kzlà</td></tr>
<tr><td></td><td class="gloss">wait-<span style="font-variant: small-caps;">1SG</span>-wait</td></tr>
<tr><td></td><td class="translation" colspan="1">'he waited for me' (<em>kzlà</em> has underlying low tone)</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (139)
</strong></td><td class="object-language" colspan="1"><em>ks-ìxà-ksà</em></td></tr>
<tr><td></td><td class="morpheme">ks-ìxà-ksà</td></tr>
<tr><td></td><td class="gloss">touch-<span style="font-variant: small-caps;">1SG</span>-touch</td></tr>
<tr><td></td><td class="translation" colspan="1">'he touched me' or 'he wounded me'</td></tr>
</tbody></table>

The form _ɗ_ is used if the verb has the stem-formative movement-away marker _í_, the point-of view of the subject marker _ú_, or some other extension(s):

<table><tbody>
<tr><td><strong>
    (140)
</strong></td><td class="object-language" colspan="1"><em>hl-ì-ɗ-á-ghá-hlà	[hl-ì-ɗáa-hlà]</em></td></tr>
<tr><td></td><td class="morpheme">hl-ì-ɗ-á-ghá-hlà</td></tr>
<tr><td></td><td class="gloss">fall-<span style="font-variant: small-caps;">AWAY-1SG-PVG-D:PVG</span>-fall</td></tr>
<tr><td></td><td class="translation" colspan="1">'he found me' (The verb <em>hlà</em> 'fall' is intransitive, and the marker <em>i</em> has a transitivizing function here.)</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (141)
</strong></td><td class="object-language" colspan="4"><em>mántsá yá ká-xə̀n mb-ì-ɗí-f-tà</em></td></tr>
<tr><td></td><td class="morpheme">mántsá</td><td class="morpheme">yá</td><td class="morpheme">ká-xə̀n</td><td class="morpheme">mb-ì-ɗí-f-tà</td></tr>
<tr><td></td><td class="gloss">like that</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP-3PL</span></td><td class="gloss">cure-<span style="font-variant: small-caps;">AWAY-1SG-UP-REF</span></td></tr>
<tr><td></td><td class="translation" colspan="4">'that is how they cured me'</td></tr>
</tbody></table>
<h3 id="Reciprocal">Reciprocal</h3>

The reciprocal function is coded by the plural subject pronoun on the verb and the noun _vghá_ ‘body’ preceded by the preposition _tá_. The difference between the reciprocal and the marking of coreferentiality is that in the reciprocal the noun _vghá_ ‘body’ is not followed by a possessive pronoun coding the person and number of the subject:

<table><tbody>
<tr><td><strong>
    (142)
</strong></td><td class="object-language" colspan="5"><em>tskáy, tà tsk-áy-lú tá vghá</em></td></tr>
<tr><td></td><td class="morpheme">tskáy,</td><td class="morpheme">tà</td><td class="morpheme">tsk-áy-lú</td><td class="morpheme">tá</td><td class="morpheme">vghá</td></tr>
<tr><td></td><td class="gloss">gathering</td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">gather:<span style="font-variant: small-caps;">POT-HUM</span></td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">body</td></tr>
<tr><td></td><td class="translation" colspan="5">'do people gather as they used to?'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (143)
</strong></td><td class="object-language" colspan="6"><em>gúyá-f-gúyà xə̀n tá vghá ndá zwánì</em></td></tr>
<tr><td></td><td class="morpheme">gúyá-f-gúyà</td><td class="morpheme">xə̀n</td><td class="morpheme">tá</td><td class="morpheme">vghá</td><td class="morpheme">ndá</td><td class="morpheme">zwánì</td></tr>
<tr><td></td><td class="gloss">meet-<span style="font-variant: small-caps;">UP</span>-meet</td><td class="gloss"><span style="font-variant: small-caps;">3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">body</td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">children</td></tr>
<tr><td></td><td class="translation" colspan="6">'they met with children'</td></tr>
</tbody></table>
<h3 id="Indirect object">Indirect object</h3>

Hdi has the category ‘indirect object’ which represents an entity C, often animate, such that when A acts on B it affects C or when the event has only one participant A, but the non-participant in the event C is affected. The nature of the affectedness is not indicated, and it may be benefactive, malefactive, or have no value in the moral domain. The way the indirect object is marked depends on the type of verb and the person of the indirect object. With verbs that do not inherently imply the presence of an indirect object, the pronoun is marked for the indirect object function through high tone on the last syllable of the verb:

<table><tbody>
<tr><td><strong>
    (144)
</strong></td><td class="object-language" colspan="1"><em>pɗ-íxà-pɗá</em></td></tr>
<tr><td></td><td class="morpheme">pɗ-íxà-pɗá</td></tr>
<tr><td></td><td class="gloss">leave-<span style="font-variant: small-caps;">1SG</span>-leave</td></tr>
<tr><td></td><td class="translation" colspan="1">'he left it for me'</td></tr>
</tbody></table>

Cf.:

<table><tbody>
<tr><td><strong>
    (145)
</strong></td><td class="object-language" colspan="1"><em>pɗ-ìxà-pɗà</em></td></tr>
<tr><td></td><td class="morpheme">pɗ-ìxà-pɗà</td></tr>
<tr><td></td><td class="gloss">leave-<span style="font-variant: small-caps;">1SG</span>-leave</td></tr>
<tr><td></td><td class="translation" colspan="1">'I was abandoned/he left me'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (146)
</strong></td><td class="object-language" colspan="6"><em>kl-í-g-í-ɗá-ghà wá kɗìx-á-ɗá, ká-’á kà wàxú</em></td></tr>
<tr><td></td><td class="morpheme">kl-í-g-í-ɗá-ghà</td><td class="morpheme">wá</td><td class="morpheme">kɗìx-á-ɗá</td><td class="morpheme">ká-’á</td><td class="morpheme">kà</td><td class="morpheme">wàxú</td></tr>
<tr><td></td><td class="gloss">take-<span style="font-variant: small-caps;">EP-INN-AWAY-1SG-D:PVG</span></td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss">donkey-<span style="font-variant: small-caps;">GEN-1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP-3SG</span></td><td class="gloss">like</td><td class="gloss">cry</td></tr>
<tr><td></td><td class="translation" colspan="6">'"Bring me back my donkey", he said, crying'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (147)
</strong></td><td class="object-language" colspan="3"><em>ɓlá-ghà-p-ɓlá tá ùdzú</em></td></tr>
<tr><td></td><td class="morpheme">ɓlá-ghà-p-ɓlá</td><td class="morpheme">tá</td><td class="morpheme">ùdzú</td></tr>
<tr><td></td><td class="gloss">break-<span style="font-variant: small-caps;">2SG-OUT</span>-break</td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">stick</td></tr>
<tr><td></td><td class="translation" colspan="3">'he broke your stick' (to your cetriment)</td></tr>
</tbody></table>

Direct affectedness is coded by low tone on the verb and high tone on the pronoun:

<table><tbody>
<tr><td><strong>
    (148)
</strong></td><td class="object-language" colspan="1"><em>ɓlà-ghá-p-ɓlà</em></td></tr>
<tr><td></td><td class="morpheme">ɓlà-ghá-p-ɓlà</td></tr>
<tr><td></td><td class="gloss">break-<span style="font-variant: small-caps;">2SG-OUT</span>-break</td></tr>
<tr><td></td><td class="translation" colspan="1">'he broke you'</td></tr>
</tbody></table>

Verbs that inherently involve an indirect object, which in Hdi include _vlá_ ‘give’ and _mná_ ‘tell’, require the indirect object marker. The unspecified indirect object is marked by the suffix _n_, glossed as 3 (third person) in Frajzyngier with Shay 2002:

<table><tbody>
<tr><td><strong>
    (149)
</strong></td><td class="object-language" colspan="3"><em>vlá-n-vl-í tá kóɓù</em></td></tr>
<tr><td></td><td class="morpheme">vlá-n-vl-í</td><td class="morpheme">tá</td><td class="morpheme">kóɓù</td></tr>
<tr><td></td><td class="gloss">give-<span style="font-variant: small-caps;">3</span>-give-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">money</td></tr>
<tr><td></td><td class="translation" colspan="3">'I gave money'</td></tr>
</tbody></table>

The marker _n_ also occurs with such verbs if the indirect object is an independent pronoun, e.g. the third-person plural pronoun _xə̀n_ or a noun. The independent pronoun and the nouns are marked by the preposition _tá_:

<table><tbody>
<tr><td><strong>
    (150)
</strong></td><td class="object-language" colspan="5"><em>vlá-n-vl-íyù tá xə̀n tá kóɓù</em></td></tr>
<tr><td></td><td class="morpheme">vlá-n-vl-íyù</td><td class="morpheme">tá</td><td class="morpheme">xə̀n</td><td class="morpheme">tá</td><td class="morpheme">kóɓù</td></tr>
<tr><td></td><td class="gloss">give-<span style="font-variant: small-caps;">3</span>-give-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss"><span style="font-variant: small-caps;">3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">money</td></tr>
<tr><td></td><td class="translation" colspan="5">'I gave him money'</td></tr>
</tbody></table>

or:

<table><tbody>
<tr><td><strong>
    (151)
</strong></td><td class="object-language" colspan="5"><em>vlá-n-vl-í tá kóɓù tá xə̀n</em></td></tr>
<tr><td></td><td class="morpheme">vlá-n-vl-í</td><td class="morpheme">tá</td><td class="morpheme">kóɓù</td><td class="morpheme">tá</td><td class="morpheme">xə̀n</td></tr>
<tr><td></td><td class="gloss">give-<span style="font-variant: small-caps;">3</span>-give-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">money</td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss"><span style="font-variant: small-caps;">3PL</span></td></tr>
<tr><td></td><td class="translation" colspan="5">'I gave them money'</td></tr>
</tbody></table>
<table><tbody>
<tr><td><strong>
    (152)
</strong></td><td class="object-language" colspan="6"><em>vlá-n-vlá mbítsá tá kóɓù tá mbáká</em></td></tr>
<tr><td></td><td class="morpheme">vlá-n-vlá</td><td class="morpheme">mbítsá</td><td class="morpheme">tá</td><td class="morpheme">kóɓù</td><td class="morpheme">tá</td><td class="morpheme">mbáká</td></tr>
<tr><td></td><td class="gloss">give-<span style="font-variant: small-caps;">3</span>-give</td><td class="gloss">Mbitsa</td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">money</td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">Mbaka</td></tr>
<tr><td></td><td class="translation" colspan="6">'Mbitsa gave money to Baka'</td></tr>
</tbody></table>

If there is a specific indirect object in the proposition, the indirect object is coded by an object pronoun. For the third person, the marker is _ná_:

<table><tbody>
<tr><td><strong>
    (153)
</strong></td><td class="object-language" colspan="538"><em>vlá-ná-vl-í tá kóɓù</em></td></tr>
<tr><td></td><td class="morpheme">vlá-ná-vl-í</td><td class="morpheme">tá</td><td class="morpheme">kóɓù</td><td class="morpheme">drá-ná-drà</td><td class="morpheme">(ngá-ní)</td><td class="morpheme">kà</td><td class="morpheme">d-ù-tà</td><td class="morpheme">kà</td><td class="morpheme">ghzú</td><td class="morpheme">mbù’á-vá-mbù’á</td><td class="morpheme">tá</td><td class="morpheme">ɗáfà</td><td class="morpheme">ndá</td><td class="morpheme">hlìhlík</td><td class="morpheme">kàp-á-n-kàpá</td><td class="morpheme">xdí</td><td class="morpheme">tá</td><td class="morpheme">ghǝ̀ŋ</td><td class="morpheme">ndá</td><td class="morpheme">hàmanyàjì</td><td class="morpheme">vàlà-dá-p-vàl-í</td><td class="morpheme">dá</td><td class="morpheme">xàdà</td><td class="morpheme">á</td><td class="morpheme">tsìɗà-dá-m-tsìɗà</td><td class="morpheme">mdú-xà</td><td class="morpheme">dà</td><td class="morpheme">dzùgùví</td><td class="morpheme">ndá</td><td class="morpheme">ǹgh-í</td><td class="morpheme">tà</td><td class="morpheme">ptà</td><td class="morpheme">mà</td><td class="morpheme">tàbá</td><td class="morpheme">tsá</td><td class="morpheme">zẁanà</td><td class="morpheme">kɗéri</td><td class="morpheme">xáɗ</td><td class="morpheme">ìm</td><td class="morpheme">gà</td><td class="morpheme">xdí</td><td class="morpheme">wù</td><td class="morpheme">kó</td><td class="morpheme">mbàɗ</td><td class="morpheme">ká</td><td class="morpheme">pákáwá ghúvì</td><td class="morpheme">kày</td><td class="morpheme">kà</td><td class="morpheme">klà-á-tà</td><td class="morpheme">ngá</td><td class="morpheme">zwàn-à-ní</td><td class="morpheme">skwá-skw-í</td><td class="morpheme">tá</td><td class="morpheme">kwà</td><td class="morpheme">tá</td><td class="morpheme">kà</td><td class="morpheme">ghə́n</td><td class="morpheme">ngá</td><td class="morpheme">múk</td><td class="morpheme">má-ghá</td><td class="morpheme">sə̀-gl-s-í</td><td class="morpheme">kà</td><td class="morpheme">másə́-gl-tá-tsí</td><td class="morpheme">ghùɓàsá-n-ghùɓàsá</td><td class="morpheme">tà-n-tà</td><td class="morpheme">tá</td><td class="morpheme">sígà</td><td class="morpheme">nù’ú-v-nù’à</td><td class="morpheme">tá</td><td class="morpheme">hlà</td><td class="morpheme">nù’-ú-nù’á</td><td class="morpheme">hlà</td><td class="morpheme">nù’á-f-nù’á</td><td class="morpheme">tá</td><td class="morpheme">hlà</td><td class="morpheme">dúkwá-f-ndá-dúkwá</td><td class="morpheme">mbítsá</td><td class="morpheme">tá</td><td class="morpheme">pìtsákw-á-ní</td><td class="morpheme">dúkwá-f-ndá-dúkw-ì</td><td class="morpheme">tá</td><td class="morpheme">sá-ghá-nì</td><td class="morpheme">mà</td><td class="morpheme">kə́l-ká</td><td class="morpheme">mà</td><td class="morpheme">kl-á-ghá-ká</td><td class="morpheme">drá-ghú-drá</td><td class="morpheme">tá</td><td class="morpheme">nìvì</td><td class="morpheme">drà-ná-ghú-drà</td><td class="morpheme">kà</td><td class="morpheme">ghùɓàsá-p-tá</td><td class="morpheme">lá</td><td class="morpheme">jíjì</td><td class="morpheme">ngá</td><td class="morpheme">lá-bà</td><td class="morpheme">m̀ndú-xà</td><td class="morpheme">ksà-gá-ghà-tà</td><td class="morpheme">kà</td><td class="morpheme">là-gá-ghà-tá-tsí</td><td class="morpheme">tá</td><td class="morpheme">hlrə́ŋ-á</td><td class="morpheme">fú</td><td class="morpheme">ká</td><td class="morpheme">ùvá</td><td class="morpheme">mántsá</td><td class="morpheme">bá</td><td class="morpheme">tà</td><td class="morpheme">dzà-í</td><td class="morpheme">ɓá</td><td class="morpheme">ká</td><td class="morpheme">ùvá</td><td class="morpheme">mántsá</td><td class="morpheme">má</td><td class="morpheme">sí</td><td class="morpheme">tà</td><td class="morpheme">dzà-í</td><td class="morpheme">mndán</td><td class="morpheme">pàtə̀k</td><td class="morpheme">ndá</td><td class="morpheme">mà</td><td class="morpheme">ghwà</td><td class="morpheme">tá</td><td class="morpheme">bgàhlà</td><td class="morpheme">kl-í-g-í-ɗá-ghà-wá</td><td class="morpheme">kɗìx-á-ɗà</td><td class="morpheme">ká-’á</td><td class="morpheme">mbsá-f</td><td class="morpheme">sígà</td><td class="morpheme">kà</td><td class="morpheme">zá</td><td class="morpheme">Pghìntà</td><td class="morpheme">kà</td><td class="morpheme">zə</td><td class="morpheme">Pghìntà</td><td class="morpheme">kà</td><td class="morpheme">wùdá-xə̀n</td><td class="morpheme">tá</td><td class="morpheme">wùdá</td><td class="morpheme">ká-’á</td><td class="morpheme">kà</td><td class="morpheme">wùdə́-xə̀n</td><td class="morpheme">tá</td><td class="morpheme">wùdá</td><td class="morpheme">ká-’á</td><td class="morpheme">mà</td><td class="morpheme">tágh-ká</td><td class="morpheme">tá</td><td class="morpheme">skál-á</td><td class="morpheme">m̀ndú</td><td class="morpheme">tà</td><td class="morpheme">z-áy-z-áy</td><td class="morpheme">tá</td><td class="morpheme">ɗàfá</td><td class="morpheme">kùl</td><td class="morpheme">xàɗ(ú)</td><td class="morpheme">ɗàlí</td><td class="morpheme">ká-xə̀n</td><td class="morpheme">mántsá</td><td class="morpheme">sí</td><td class="morpheme">ndá</td><td class="morpheme">gá</td><td class="morpheme">ká</td><td class="morpheme">ndá</td><td class="morpheme">rvíɗìk</td><td class="morpheme">dzà’á</td><td class="morpheme">phlá-phlá-xə̀ŋ</td><td class="morpheme">tá</td><td class="morpheme">m̀ndú</td><td class="morpheme">dzà’á</td><td class="morpheme">hlə̀v-áy</td><td class="morpheme">tá</td><td class="morpheme">índà</td><td class="morpheme">m̀ndú</td><td class="morpheme">ks-ú-tà</td><td class="morpheme">á</td><td class="morpheme">krì</td><td class="morpheme">tá</td><td class="morpheme">ùvá</td><td class="morpheme">wà</td><td class="morpheme">kà</td><td class="morpheme">dzà’á</td><td class="morpheme">krì</td><td class="morpheme">ks-ú-tà</td><td class="morpheme">ùvá</td><td class="morpheme">vlá-ghá-vlá-xə̀n</td><td class="morpheme">tá</td><td class="morpheme">kób-à-ɗá</td><td class="morpheme">vlá-ghá-vlá-xə̀n</td><td class="morpheme">rà</td><td class="morpheme">xd-íyù</td><td class="morpheme">r-ké</td><td class="morpheme">xd-íyù</td><td class="morpheme">rà</td><td class="morpheme">wá</td><td class="morpheme">ɗghá</td><td class="morpheme">nà</td><td class="morpheme">nə</td><td class="morpheme">bà-f-tsí</td><td class="morpheme">nú</td><td class="morpheme">bà-f-tsí</td><td class="morpheme">nə</td><td class="morpheme">tá</td><td class="morpheme">klà-gá-ghá-f-tà</td><td class="morpheme">tà</td><td class="morpheme">ná</td><td class="morpheme">fú</td><td class="morpheme">ná</td><td class="morpheme">nà</td><td class="morpheme">ká-’á</td><td class="morpheme">ì</td><td class="morpheme">wá</td><td class="morpheme">tá</td><td class="morpheme">phlà-ná-p-tà</td><td class="morpheme">dà-ná-tá</td><td class="morpheme">wá-ká</td><td class="morpheme">tá</td><td class="morpheme">ɗàfá</td><td class="morpheme">wá</td><td class="morpheme">ká</td><td class="morpheme">Mbitsa</td><td class="morpheme">lá-ghú-í</td><td class="morpheme">dá</td><td class="morpheme">Nigeria</td><td class="morpheme">ngú</td><td class="morpheme">tà</td><td class="morpheme">zá</td><td class="morpheme">ká</td><td class="morpheme">ɗvà</td><td class="morpheme">‘á</td><td class="morpheme">xdí-xà</td><td class="morpheme">tá</td><td class="morpheme">l’école</td><td class="morpheme">wù</td><td class="morpheme">ká-’á</td><td class="morpheme">xámáyádzì</td><td class="morpheme">á</td><td class="morpheme">wà</td><td class="morpheme">xàɗ</td><td class="morpheme">áŋni</td><td class="morpheme">tà</td><td class="morpheme">mtà-kú</td><td class="morpheme">ndá</td><td class="morpheme">mtà</td><td class="morpheme">wà</td><td class="morpheme">xàɗ</td><td class="morpheme">kóɓ</td><td class="morpheme">dà</td><td class="morpheme">tsí</td><td class="morpheme">wà</td><td class="morpheme">tà</td><td class="morpheme">xwáyá</td><td class="morpheme">í’í</td><td class="morpheme">tà</td><td class="morpheme">xàní</td><td class="morpheme">kàghá</td><td class="morpheme">yà</td><td class="morpheme">yá</td><td class="morpheme">gwì’yán</td><td class="morpheme">yá</td><td class="morpheme">dágálá</td><td class="morpheme">à</td><td class="morpheme">á</td><td class="morpheme">gwì’yán</td><td class="morpheme">á</td><td class="morpheme">dágálá</td><td class="morpheme">tsá</td><td class="morpheme">Gulu</td><td class="morpheme">yá</td><td class="morpheme">ná</td><td class="morpheme">yà-yà</td><td class="morpheme">tá</td><td class="morpheme">zwànì</td><td class="morpheme">ndá</td><td class="morpheme">ndghà</td><td class="morpheme">xìyá</td><td class="morpheme">xìyá</td><td class="morpheme">skwì</td><td class="morpheme">txàf-í</td><td class="morpheme">tà</td><td class="morpheme">ná</td><td class="morpheme">ɗèlèwèr</td><td class="morpheme">ná</td><td class="morpheme">ná</td><td class="morpheme">skwì</td><td class="morpheme">3</td><td class="morpheme">nghá-nà-ghá-tsí</td><td class="morpheme">índà</td><td class="morpheme">dimanche</td><td class="morpheme">ná</td><td class="morpheme">màmú</td><td class="morpheme">marriage</td><td class="morpheme">ndánà</td><td class="morpheme">kà</td><td class="morpheme">m̀ndú</td><td class="morpheme">yà</td><td class="morpheme">dágálá</td><td class="morpheme">tíkvá</td><td class="morpheme">gàvlì</td><td class="morpheme">tá</td><td class="morpheme">mn-áy</td><td class="morpheme">kà-zlày</td><td class="morpheme">ná</td><td class="morpheme">sí</td><td class="morpheme">m̀ndú</td><td class="morpheme">dzì’í</td><td class="morpheme">rà</td><td class="morpheme">tá</td><td class="morpheme">krì</td><td class="morpheme">dzì’í</td><td class="morpheme">tsá</td><td class="morpheme">yá</td><td class="morpheme">skwì</td><td class="morpheme">tà</td><td class="morpheme">xgù-lù</td><td class="morpheme">kà</td><td class="morpheme">zə̀gláftà</td><td class="morpheme">màmú</td><td class="morpheme">sàn</td><td class="morpheme">m̀ghám</td><td class="morpheme">tá</td><td class="morpheme">kl-áf-tá</td><td class="morpheme">màràkw</td><td class="morpheme">xìs</td><td class="morpheme">xìyá-xìyá</td><td class="morpheme">skwì</td><td class="morpheme">txá-f-ì</td><td class="morpheme">tà</td><td class="morpheme">ná</td><td class="morpheme">ɗélèwèr</td><td class="morpheme">ná</td><td class="morpheme">ná</td><td class="morpheme">bàɗú</td><td class="morpheme">xú’ú-á</td><td class="morpheme">tsá</td><td class="morpheme">zíndíŋ</td><td class="morpheme">yá</td><td class="morpheme">ngá</td><td class="morpheme">dà</td><td class="morpheme">tá</td><td class="morpheme">mbízà</td><td class="morpheme">ngá</td><td class="morpheme">làɓà-ná-f-tà</td><td class="morpheme">ndá</td><td class="morpheme">ghúv-à</td><td class="morpheme">gù</td><td class="morpheme">ngá</td><td class="morpheme">vlá-n</td><td class="morpheme">tá</td><td class="morpheme">zwàn-ì</td><td class="morpheme">tsghà-dá-f</td><td class="morpheme">xáxə̀n</td><td class="morpheme">tá</td><td class="morpheme">sànì</td><td class="morpheme">lá-ghà-ní</td><td class="morpheme">mbàɗ</td><td class="morpheme">ká</td><td class="morpheme">kà</td><td class="morpheme">tsghà-dá-f-tá</td><td class="morpheme">sànì</td><td class="morpheme">zlíbí</td><td class="morpheme">lá-ghà</td><td class="morpheme">pákáẁ ghúvì</td><td class="morpheme">kày</td><td class="morpheme">kà</td><td class="morpheme">lá-b</td><td class="morpheme">díngá-f-tá</td><td class="morpheme">tsá</td><td class="morpheme">mbízà</td><td class="morpheme">yà</td><td class="morpheme">twák</td><td class="morpheme">rí</td><td class="morpheme">gù</td><td class="morpheme">á nà</td><td class="morpheme">mágá-mágá</td><td class="morpheme">rí</td><td class="morpheme">mágá</td><td class="morpheme">à</td><td class="morpheme">wà</td><td class="morpheme">á nà</td><td class="morpheme">ksá-f-tà</td><td class="morpheme">dángwà</td><td class="morpheme">t-íì</td><td class="morpheme">kày</td><td class="morpheme">mántsá</td><td class="morpheme">wà</td><td class="morpheme">lá-x-à-ɗá</td><td class="morpheme">tà</td><td class="morpheme">lòpitál</td><td class="morpheme">má</td><td class="morpheme">xàɗú</td><td class="morpheme">kwóbù</td><td class="morpheme">lá</td><td class="morpheme">ká-xə̀n</td><td class="morpheme">mná-ná-tà</td><td class="morpheme">ká</td><td class="morpheme">yàgh</td><td class="morpheme">mántsá</td><td class="morpheme">ɗífà-úgh-ɗífà</td><td class="morpheme">xád</td><td class="morpheme">yà</td><td class="morpheme">ká</td><td class="morpheme">yàgh</td><td class="morpheme">sá-ghá-sá</td><td class="morpheme">ká-xə̀n</td><td class="morpheme">ndá</td><td class="morpheme">í’í</td><td class="morpheme">wá-ná-f-wá</td><td class="morpheme">ná</td><td class="morpheme">máhláká-ɗá</td><td class="morpheme">ná</td><td class="morpheme">ká-’á</td><td class="morpheme">ndá</td><td class="morpheme">dùxwál-xà-ní</td><td class="morpheme">ìr-á-w</td><td class="morpheme">ná</td><td class="morpheme">nà</td><td class="morpheme">dá</td><td class="morpheme">ká-’á</td><td class="morpheme">ɗáwà-n-tà</td><td class="morpheme">dà</td><td class="morpheme">tsí</td><td class="morpheme">kà</td><td class="morpheme">yàwú</td><td class="morpheme">ndzà-kw-à-gá-p-tà</td><td class="morpheme">xdí</td><td class="morpheme">màndá</td><td class="morpheme">ghàlíyá</td><td class="morpheme">ndá</td><td class="morpheme">sná-xə̀ŋ</td><td class="morpheme">kà</td><td class="morpheme">zlày</td><td class="morpheme">ná</td><td class="morpheme">índà</td><td class="morpheme">m̀ndú-xà</td><td class="morpheme">tá</td><td class="morpheme">mtú-tà</td><td class="morpheme">ná</td><td class="morpheme">ngá</td><td class="morpheme">ɗékɗék</td><td class="morpheme">á</td><td class="morpheme">wù</td><td class="morpheme">ká-’á</td><td class="morpheme">ndzɗà-vá-tà</td><td class="morpheme">pákáwá ghúvì</td><td class="morpheme">tá</td><td class="morpheme">xvá</td><td class="morpheme">tà</td><td class="morpheme">ǹghə́-tsə́</td><td class="morpheme">ná</td><td class="morpheme">mbàɗ</td><td class="morpheme">ká</td><td class="morpheme">zíngá</td><td class="morpheme">kà</td><td class="morpheme">sá-ghà</td><td class="morpheme">kà</td><td class="morpheme">lá-ghá</td><td class="morpheme">vàzák</td><td class="morpheme">ndzɗà-vá-tà</td><td class="morpheme">vàzák</td><td class="morpheme">tà</td><td class="morpheme">xvá</td><td class="morpheme">tà</td><td class="morpheme">ǹghə́-tsí</td><td class="morpheme">ná</td><td class="morpheme">kà</td><td class="morpheme">sá-ghá</td><td class="morpheme">ùvá</td><td class="morpheme">kabgà</td><td class="morpheme">tà</td><td class="morpheme">kúm-ày-ì</td><td class="morpheme">tá</td><td class="morpheme">wàná-f-tá</td><td class="morpheme">ná</td><td class="morpheme">máhláká-ɗá</td><td class="morpheme">ná</td><td class="morpheme">ndzdà-vá-tà</td><td class="morpheme">ùvá</td><td class="morpheme">tà</td><td class="morpheme">xvá</td><td class="morpheme">tà</td><td class="morpheme">ǹghə́-l</td><td class="morpheme">ná</td><td class="morpheme">kà</td><td class="morpheme">sá-ghá</td><td class="morpheme">krì</td><td class="morpheme">kà</td><td class="morpheme">ndzɗà-vá-tá</td><td class="morpheme">ùvá</td><td class="morpheme">tà</td><td class="morpheme">xvá</td><td class="morpheme">lá-mà</td><td class="morpheme">krì</td><td class="morpheme">dá</td><td class="morpheme">xàd-à</td><td class="morpheme">kà</td><td class="morpheme">hlà-ná-ghá-tá-tsí</td><td class="morpheme">t-úvá</td><td class="morpheme">xàɗú</td><td class="morpheme">kóɓù</td><td class="morpheme">ngá</td><td class="morpheme">mágà</td><td class="morpheme">lèkól</td><td class="morpheme">wà</td><td class="morpheme">dzà’á</td><td class="morpheme">phlá-phlá-xə̀n</td><td class="morpheme">tá</td><td class="morpheme">m̀ndú</td><td class="morpheme">kàbgà</td><td class="morpheme">xáxə̀ŋ</td><td class="morpheme">tá</td><td class="morpheme">dzà-tá</td><td class="morpheme">dá-ɗá</td><td class="morpheme">ká</td><td class="morpheme">gawa</td><td class="morpheme">kà</td><td class="morpheme">tà</td><td class="morpheme">ɗv-áy</td><td class="morpheme">lázgláftà</td><td class="morpheme">tà</td><td class="morpheme">ɗv-áy</td><td class="morpheme">lázgláftà</td><td class="morpheme">là</td><td class="morpheme">dz-ú-dzá</td><td class="morpheme">kághá</td><td class="morpheme">ná</td><td class="morpheme">xgà-n-tà-ì</td><td class="morpheme">tá</td><td class="morpheme">gwì’yán</td><td class="morpheme">wà</td><td class="morpheme">ká-’á</td><td class="morpheme">má</td><td class="morpheme">tà</td><td class="morpheme">kúm-tá-ká</td><td class="morpheme">tá</td><td class="morpheme">nzà-kú</td><td class="morpheme">mà</td><td class="morpheme">túrú</td></tr>
<tr><td></td><td class="gloss">give-<span style="font-variant: small-caps;">DEM</span>-give-<span style="font-variant: small-caps;">1</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">money</td><td class="gloss">burn-<span style="font-variant: small-caps;">DEM</span>-burn</td><td class="gloss"><span style="font-variant: small-caps;">FOR-3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">cook-<span style="font-variant: small-caps;">SO-REF</span></td><td class="gloss"><span style="font-variant: small-caps;">AS/INTO</span></td><td class="gloss">beer</td><td class="gloss">eat.without.the.sauce-<span style="font-variant: small-caps;">AS</span>-eat.without.the.sauce</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">mush</td><td class="gloss">with</td><td class="gloss">eggs</td><td class="gloss">raise-<span style="font-variant: small-caps;">GO-TENT</span>-raise</td><td class="gloss">Hdi</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">head</td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">Hamman Yaji </td><td class="gloss">jump-<span style="font-variant: small-caps;">ALL-OUT</span>-jump-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">TO</span></td><td class="gloss">here</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">enter-<span style="font-variant: small-caps;">ALL-IN</span>-enter</td><td class="gloss">people-<span style="font-variant: small-caps;">PL</span></td><td class="gloss"><span style="font-variant: small-caps;">TO</span></td><td class="gloss">room</td><td class="gloss"><span style="font-variant: small-caps;">STAT</span></td><td class="gloss">see-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">mat</td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">center</td><td class="gloss"><span style="font-variant: small-caps;">DEF</span></td><td class="gloss">child:<span style="font-variant: small-caps;">PL-GEN</span></td><td class="gloss">Kderi</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss">water</td><td class="gloss">in</td><td class="gloss">Hdi</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss"><span style="font-variant: small-caps;">Q (H)</span></td><td class="gloss">then</td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">hyena</td><td class="gloss"><span style="font-variant: small-caps;">INTERJ</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">take-<span style="font-variant: small-caps;">PART-REF</span></td><td class="gloss">for</td><td class="gloss">child:<span style="font-variant: small-caps;">PL-GEN-3SG</span></td><td class="gloss">buy-buy-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">calabash</td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">head</td><td class="gloss">for</td><td class="gloss">girl</td><td class="gloss">mother-<span style="font-variant: small-caps;">2SG</span></td><td class="gloss">drink-<span style="font-variant: small-caps;">AGAIN</span>-drink-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">apply.ointment-<span style="font-variant: small-caps;">AGAIN-REF-3SG</span></td><td class="gloss">laugh-<span style="font-variant: small-caps;">TENT</span>-laugh</td><td class="gloss">burst-<span style="font-variant: small-caps;">TENT</span>-burst</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">pot</td><td class="gloss">fatten-<span style="font-variant: small-caps;">AS</span>-fatten</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">cow</td><td class="gloss">fatten-<span style="font-variant: small-caps;">SO</span>-fatten</td><td class="gloss">cow</td><td class="gloss">fatten-<span style="font-variant: small-caps;">UP</span>-fatten</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">cow</td><td class="gloss">find-<span style="font-variant: small-caps;">UP-ASSC</span>-find</td><td class="gloss">Mbitsa</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">hoe-<span style="font-variant: small-caps;">GEN-3SG</span></td><td class="gloss">find-<span style="font-variant: small-caps;">UP-ASSC</span>-find-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">hoe-<span style="font-variant: small-caps;">GEN-3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">PROH</span></td><td class="gloss">take-<span style="font-variant: small-caps;">2SG</span></td><td class="gloss"><span style="font-variant: small-caps;">PROH</span></td><td class="gloss">take-<span style="font-variant: small-caps;">GO-D:GO-2SG</span></td><td class="gloss">burn-<span style="font-variant: small-caps;">D:SO</span>-burn</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">firewood</td><td class="gloss">burn-<span style="font-variant: small-caps;">TENT-D:SO</span>-burn</td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">laugh-<span style="font-variant: small-caps;">OUT-REF</span></td><td class="gloss">people</td><td class="gloss">in-laws</td><td class="gloss"><span style="font-variant: small-caps;">NORM</span></td><td class="gloss">go-<span style="font-variant: small-caps;">OUT</span></td><td class="gloss">man-<span style="font-variant: small-caps;">PL</span></td><td class="gloss">catch-<span style="font-variant: small-caps;">INN-D:PVG-REF:SUBJ</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">dig-<span style="font-variant: small-caps;">INN-D:PVG-REF-3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">root-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">tree</td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">cat</td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss"><span style="font-variant: small-caps;">HYP</span></td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">go-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">HYP</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">cat</td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss"><span style="font-variant: small-caps;">HYP</span></td><td class="gloss"><span style="font-variant: small-caps;">PAST</span></td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">go-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss">but</td><td class="gloss">perhaps</td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss"><span style="font-variant: small-caps;">IN</span></td><td class="gloss">river</td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">Bgahla</td><td class="gloss">take-<span style="font-variant: small-caps;">EP-INN-AWAY-1SG-GO-PL</span></td><td class="gloss">donkey-<span style="font-variant: small-caps;">GEN-1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP-3SG</span></td><td class="gloss">cover-<span style="font-variant: small-caps;">UP</span></td><td class="gloss">pot</td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">eat</td><td class="gloss">Phinta</td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">eat</td><td class="gloss">Phinta</td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">fight-<span style="font-variant: small-caps;">3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">fight</td><td class="gloss"><span style="font-variant: small-caps;">COMP-3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">fight-<span style="font-variant: small-caps;">3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">fight</td><td class="gloss"><span style="font-variant: small-caps;">COMP-3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">PROH</span></td><td class="gloss">learn-<span style="font-variant: small-caps;">2SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">dance-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">man</td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">eat-<span style="font-variant: small-caps;">PO</span>-eat-<span style="font-variant: small-caps;">PO</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">mush</td><td class="gloss">without</td><td class="gloss">lack</td><td class="gloss">sauce</td><td class="gloss"><span style="font-variant: small-caps;">COMP-3PL</span></td><td class="gloss">like.that</td><td class="gloss"><span style="font-variant: small-caps;">PAST</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">where</td><td class="gloss"><span style="font-variant: small-caps;">2SG</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">night</td><td class="gloss"><span style="font-variant: small-caps;">FUT</span></td><td class="gloss">kill.<span style="font-variant: small-caps;">PL</span>-kill.<span style="font-variant: small-caps;">PL-3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">man</td><td class="gloss"><span style="font-variant: small-caps;">FUT</span></td><td class="gloss">hit-<span style="font-variant: small-caps;">PO</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">all</td><td class="gloss">man-<span style="font-variant: small-caps;">PL</span></td><td class="gloss">devour-<span style="font-variant: small-caps;">SO-REF</span></td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss">dog</td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">cat</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss"><span style="font-variant: small-caps;">FUT</span></td><td class="gloss">dog</td><td class="gloss">devour-<span style="font-variant: small-caps;">SO-REF</span></td><td class="gloss">cat</td><td class="gloss">give-<span style="font-variant: small-caps;">2SG</span>-give-<span style="font-variant: small-caps;">3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">money-<span style="font-variant: small-caps;">GEN-1SG</span></td><td class="gloss">spend.night-spend.night-<span style="font-variant: small-caps;">2SG</span></td><td class="gloss"><span style="font-variant: small-caps;">Q</span></td><td class="gloss">Hdi-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">Q-INTERJ</span></td><td class="gloss">Hdi-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">Q</span></td><td class="gloss">who</td><td class="gloss">blacksmith</td><td class="gloss"><span style="font-variant: small-caps;">Q</span></td><td class="gloss">what</td><td class="gloss">build<span style="font-variant: small-caps;">UP-3SG</span></td><td class="gloss">which thing</td><td class="gloss">build<span style="font-variant: small-caps;">UP-3SG</span></td><td class="gloss">what</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">take<span style="font-variant: small-caps;">INN-2SG-UP-REF</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">tree</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">Q</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP-3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC.PL</span></td><td class="gloss">who</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">break-<span style="font-variant: small-caps;">DEM-UP-REF</span></td><td class="gloss">cook-<span style="font-variant: small-caps;">DEM-REF</span></td><td class="gloss">who-<span style="font-variant: small-caps;">2SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">food</td><td class="gloss">how</td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">Mbitsa</td><td class="gloss">go-<span style="font-variant: small-caps;">D:SO-REF</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">Nigeria</td><td class="gloss">why</td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">eat</td><td class="gloss"><span style="font-variant: small-caps;">2SG</span></td><td class="gloss">like</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss">Hdi-<span style="font-variant: small-caps;">PL</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">school (fr.)</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP-3SG</span></td><td class="gloss">Hamayadzi</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss">lack</td><td class="gloss"><span style="font-variant: small-caps;">1PL:EXCL</span></td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">die-<span style="font-variant: small-caps;">ABS</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">die</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss">lack</td><td class="gloss">money</td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss"><span style="font-variant: small-caps;">3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">run</td><td class="gloss"><span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">sleep</td><td class="gloss"><span style="font-variant: small-caps;">2SG</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">elephant</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">large</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">elephant</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">large</td><td class="gloss"><span style="font-variant: small-caps;">DEF</span></td><td class="gloss">Gulu</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">give.birth-give.birth</td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">child:<span style="font-variant: small-caps;">PL</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">many</td><td class="gloss">corn</td><td class="gloss">corn</td><td class="gloss">thing</td><td class="gloss">expel-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">notebook</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">thing</td><td class="gloss">three</td><td class="gloss">look-<span style="font-variant: small-caps;">DEM-D:GO-3SG</span></td><td class="gloss">every</td><td class="gloss">sunday (fr.)</td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">exist</td><td class="gloss">marriage</td><td class="gloss">now</td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">man</td><td class="gloss"><span style="font-variant: small-caps;">COP</span></td><td class="gloss">important</td><td class="gloss">Tikva</td><td class="gloss">Gavli</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">say-<span style="font-variant: small-caps;">PO</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ-COMP</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss"><span style="font-variant: small-caps;">PAST</span></td><td class="gloss">man</td><td class="gloss">kill-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">Q</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">dog</td><td class="gloss">kill-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">DEF</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">thing</td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">call-<span style="font-variant: small-caps;">UH</span></td><td class="gloss">as</td><td class="gloss">zə̀gláftà</td><td class="gloss">exist</td><td class="gloss">certain</td><td class="gloss">chief</td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">take-<span style="font-variant: small-caps;">UP-REF</span></td><td class="gloss">wife</td><td class="gloss">two</td><td class="gloss">corn-corn</td><td class="gloss">thing</td><td class="gloss">expel-<span style="font-variant: small-caps;">UP-1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">book</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">day</td><td class="gloss">pound-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss"><span style="font-variant: small-caps;">DEF</span></td><td class="gloss">germinated corn</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">NORM</span></td><td class="gloss">cook</td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">bean dish</td><td class="gloss"><span style="font-variant: small-caps;">NORM</span></td><td class="gloss">mix-<span style="font-variant: small-caps;">DEM-UP-REF</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">excrement-<span style="font-variant: small-caps;">GEN</span></td><td class="gloss">goat</td><td class="gloss"><span style="font-variant: small-caps;">NORM</span></td><td class="gloss">give-<span style="font-variant: small-caps;">3</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">child-<span style="font-variant: small-caps;">PL</span></td><td class="gloss">put.up-<span style="font-variant: small-caps;">ALL-UP</span></td><td class="gloss"><span style="font-variant: small-caps;">3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">one</td><td class="gloss">go-<span style="font-variant: small-caps;">D:PVG-3SG</span></td><td class="gloss">then</td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">send-<span style="font-variant: small-caps;">ALL-UP-REF</span></td><td class="gloss">one</td><td class="gloss">bag</td><td class="gloss">go-<span style="font-variant: small-caps;">D:PVG</span></td><td class="gloss">hyena</td><td class="gloss">thus</td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">go-<span style="font-variant: small-caps;">OUT</span></td><td class="gloss">put.on.fire-<span style="font-variant: small-caps;">UP-REF</span></td><td class="gloss"><span style="font-variant: small-caps;">DEF</span></td><td class="gloss">bean dish</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">sheep</td><td class="gloss"><span style="font-variant: small-caps;">Q</span></td><td class="gloss">goat</td><td class="gloss">or</td><td class="gloss">do-do</td><td class="gloss"><span style="font-variant: small-caps;">Q</span></td><td class="gloss">do</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss">or</td><td class="gloss">catch-<span style="font-variant: small-caps;">UP-REF:SUBJ</span></td><td class="gloss">illness</td><td class="gloss"><span style="font-variant: small-caps;">OBJ-1SG</span></td><td class="gloss">then</td><td class="gloss">then</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss">go-<span style="font-variant: small-caps;">DOWN-1SG-GO</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">hospital (fr.)</td><td class="gloss">but</td><td class="gloss">lack</td><td class="gloss">money</td><td class="gloss">go</td><td class="gloss"><span style="font-variant: small-caps;">COMP-3PL</span></td><td class="gloss">tell-<span style="font-variant: small-caps;">3SG-REF</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">squirrel</td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">hide-<span style="font-variant: small-caps;">SO</span>-hide</td><td class="gloss">here</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">squirrel</td><td class="gloss">arrive-<span style="font-variant: small-caps;">D:PVG</span>-arrive</td><td class="gloss"><span style="font-variant: small-caps;">COMP-3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss"><span style="font-variant: small-caps;">1SG</span></td><td class="gloss">walk.around-<span style="font-variant: small-caps;">DEM-UP</span>-walk.around</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">wall-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP-3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">ASSC</span></td><td class="gloss">youngster-<span style="font-variant: small-caps;">PL-3SG</span></td><td class="gloss">eye-<span style="font-variant: small-caps;">GEN</span>-who</td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">Q</span></td><td class="gloss">father</td><td class="gloss"><span style="font-variant: small-caps;">COMP-3SG</span></td><td class="gloss">ask-<span style="font-variant: small-caps;">3-REF</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss"><span style="font-variant: small-caps;">3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">when</td><td class="gloss">settle-<span style="font-variant: small-caps;">ABS-GO-INN-OUT-REF</span></td><td class="gloss">Hdi</td><td class="gloss">since</td><td class="gloss">old.time</td><td class="gloss"><span style="font-variant: small-caps;">STAT</span></td><td class="gloss">know-<span style="font-variant: small-caps;">3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">all</td><td class="gloss">man-<span style="font-variant: small-caps;">PL</span></td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">die-<span style="font-variant: small-caps;">REF</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">FOR</span></td><td class="gloss">finish</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">last-<span style="font-variant: small-caps;">AS-REF</span></td><td class="gloss">hyena</td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">work</td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">see-<span style="font-variant: small-caps;">3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">then</td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">Zinga</td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">arrive-<span style="font-variant: small-caps;">D:PVG</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">go-<span style="font-variant: small-caps;">D:GO</span></td><td class="gloss">rooster</td><td class="gloss">remain-<span style="font-variant: small-caps;">AS-REF:SUBJ</span></td><td class="gloss">rooster</td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">work</td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">see-<span style="font-variant: small-caps;">3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">arrive-<span style="font-variant: small-caps;">D:GO</span></td><td class="gloss">cat</td><td class="gloss">because</td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">want-<span style="font-variant: small-caps;">PO-1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">build-<span style="font-variant: small-caps;">UP-REF</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">wall-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">last-<span style="font-variant: small-caps;">AS-REF</span></td><td class="gloss">cat</td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">work</td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">see-<span style="font-variant: small-caps;">UH</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">arrive-<span style="font-variant: small-caps;">D:PVG</span></td><td class="gloss">dog</td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">stay-<span style="font-variant: small-caps;">AS-REF</span></td><td class="gloss">cat</td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">work</td><td class="gloss">go-<span style="font-variant: small-caps;">IN</span></td><td class="gloss">dog</td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">here-<span style="font-variant: small-caps;">DEM</span></td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss">find-<span style="font-variant: small-caps;">DEM-D:PVG-REF-3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span>-cat</td><td class="gloss">lack</td><td class="gloss">money</td><td class="gloss"><span style="font-variant: small-caps;">FOR</span></td><td class="gloss">do</td><td class="gloss">school</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss"><span style="font-variant: small-caps;">FUT</span></td><td class="gloss">kill-kill-<span style="font-variant: small-caps;">3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">man</td><td class="gloss">because</td><td class="gloss"><span style="font-variant: small-caps;">3PL</span></td><td class="gloss"><span style="font-variant: small-caps;">COM</span></td><td class="gloss">kill-<span style="font-variant: small-caps;">REF</span></td><td class="gloss">father-<span style="font-variant: small-caps;">1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP</span></td><td class="gloss">Gawa</td><td class="gloss"><span style="font-variant: small-caps;">SEQ</span></td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">like-<span style="font-variant: small-caps;">PO</span></td><td class="gloss">god</td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">like-<span style="font-variant: small-caps;">PO</span></td><td class="gloss">god</td><td class="gloss"><span style="font-variant: small-caps;">COND</span></td><td class="gloss">go-<span style="font-variant: small-caps;">SO</span>-go</td><td class="gloss"><span style="font-variant: small-caps;">2SG</span></td><td class="gloss"><span style="font-variant: small-caps;">DEM</span></td><td class="gloss">call-<span style="font-variant: small-caps;">3-REF-1SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">elephant</td><td class="gloss"><span style="font-variant: small-caps;">NEG</span></td><td class="gloss"><span style="font-variant: small-caps;">COMP-3SG</span></td><td class="gloss"><span style="font-variant: small-caps;">HYP</span></td><td class="gloss"><span style="font-variant: small-caps;">IMPF</span></td><td class="gloss">want-<span style="font-variant: small-caps;">REF-2SG</span></td><td class="gloss"><span style="font-variant: small-caps;">OBJ</span></td><td class="gloss">stay-<span style="font-variant: small-caps;">ABS</span></td><td class="gloss"><span style="font-variant: small-caps;">PREP</span></td><td class="gloss">Tourou</td></tr>
<tr><td></td><td class="translation" colspan="538">'I gave him (specific person) money'</td></tr>
</tbody></table>

